#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class pairing_between_interface_zones_only(Boolean):
    """
    Pairing between interface zones only.
    """

    fluent_name = "pairing-between-interface-zones-only?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class log_scale(Boolean):
    """
    Enable/disable the use of a log scale.
    """

    fluent_name = "log-scale?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class one_to_one_pairing(Boolean):
    """
    'one_to_one_pairing' child.
    """

    fluent_name = "one-to-one-pairing?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class under_relaxation_factor(Real):
    """
    Specify under-relaxation factor to be used in 
    the diagonal matrix elements of implicit solver.
    """

    fluent_name = "under-relaxation-factor"




import itertools
import threading
from typing import Callable, Optional


class StreamingService:
    """Encapsulates a Fluent streaming service."""

    _service_id = itertools.count()

    def __init__(self, stream_begin_method, target, streaming_service):
        """__init__ method of StreamingService class."""
        self._lock: threading.RLock = threading.RLock()
        self._streaming: bool = False
        self._id = f"stream-{next(StreamingService._service_id)}"
        self._stream_begin_method = stream_begin_method
        self._target = target
        self._streaming_service = streaming_service
        self._stream_thread: Optional[threading.Thread] = None
        self._service_callback_id = itertools.count()
        self._service_callbacks: dict = {}

    @property
    def is_streaming(self):
        """Checks whether it is streaming."""
        with self._lock:
            return self._streaming

    def register_callback(self, call_back: Callable, *args, **kwargs) -> str:
        """Register the callback.

        Parameters
        ----------
        call_back : Callable
            Callback to register.

        Returns
        -------
        str
            Registered callback ID.
        """
        with self._lock:
            callback_id = f"{next(self._service_callback_id)}"
            self._service_callbacks[callback_id] = [call_back, args, kwargs]
            return callback_id

    def unregister_callback(self, callback_id: str):
        """Unregister the callback.

        Parameters
        ----------
        callback_id : str
            ID of the registered callback.
        """
        with self._lock:
            if callback_id in self._service_callbacks:
                del self._service_callbacks[callback_id]

    def start(self, *args, **kwargs) -> None:
        """Start streaming of Fluent transcript."""
        with self._lock:
            if not self.is_streaming:
                self._prepare()
                started_evt = threading.Event()
                self._stream_thread = threading.Thread(
                    target=self._target,
                    args=(
                        self,
                        self._id,
                        self._stream_begin_method,
                        started_evt,
                        *args,
                    ),
                    kwargs=kwargs,
                )
                self._stream_thread.start()
                started_evt.wait()
                self._streaming = True

    def stop(self) -> None:
        """Stop streaming of Fluent transcript."""
        if self.is_streaming:
            self._streaming_service.end_streaming(self._id, self._stream_begin_method)
            self._stream_thread.join()
            self._streaming = False
            self._stream_thread = None

    def refresh(self, session_id, event_info) -> None:
        """Refresh stream.

        Parameters
        ----------
        session_id : str
            Name of the monitor set.
        event_info : object
            Event info object.

        Returns
        -------
        None
        """
        with self._lock_refresh:
            self.stop()
            self.start()

    def _prepare(self):
        pass  # Currently only used by monitor services.



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class plotting_grid_interval_size(Real):
    """
    'plotting_grid_interval_size' child.
    """

    fluent_name = "plotting-grid-interval-size"




import os

from ansys.fluent.core.services.scheme_eval import SchemeEval, SchemeEvalService


class ApiUpgradeAdvisor:
    def __init__(self, channel, metadata, fluent_error_state, version, mode):
        self._scheme_eval = SchemeEval(
            SchemeEvalService(channel, metadata, fluent_error_state)
        ).scheme_eval
        self._version = version
        self._mode = mode

    def _can_advise(self):
        return (
            not os.getenv("PYFLUENT_SKIP_API_UPGRADE_ADVICE")
            and self._version >= "23.1"
            and self._mode == "solver"
        )

    def __enter__(self):
        if self._can_advise():
            self._scheme_eval("(define pyfluent-journal-str-port (open-output-string))")
            self._scheme_eval("(api-echo-python-port pyfluent-journal-str-port)")
        return self

    def __exit__(self, exc_type, exc_value, exc_tb):
        if self._can_advise():
            self._scheme_eval("(api-unecho-python-port pyfluent-journal-str-port)")
            journal_str = self._scheme_eval(
                "(close-output-port pyfluent-journal-str-port)"
            ).strip()
            if (
                journal_str.startswith("solver.")
                and not journal_str.startswith("solver.tui")
                and not journal_str.startswith("solver.execute_tui")
            ):
                print(
                    "The following solver settings object method could also be used to execute the above command:"
                )
                print(f"<solver_session>.{journal_str[len('solver.'):]}")



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_10 import option as option_cls
from .vibrational_modes import vibrational_modes as vibrational_modes_cls
from .value_1 import value as value_cls
class characteristic_vibrational_temperature(Group):
    """
    'characteristic_vibrational_temperature' child.
    """

    fluent_name = "characteristic-vibrational-temperature"

    child_names = \
        ['option', 'vibrational_modes', 'value']

    option: option_cls = option_cls
    """
    option child of characteristic_vibrational_temperature.
    """
    vibrational_modes: vibrational_modes_cls = vibrational_modes_cls
    """
    vibrational_modes child of characteristic_vibrational_temperature.
    """
    value: value_cls = value_cls
    """
    value child of characteristic_vibrational_temperature.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .change_type import change_type as change_type_cls
from .pressure_far_field_child import pressure_far_field_child

class pressure_far_field(NamedObject[pressure_far_field_child], _CreatableNamedObjectMixin[pressure_far_field_child]):
    """
    'pressure_far_field' child.
    """

    fluent_name = "pressure-far-field"

    command_names = \
        ['change_type']

    change_type: change_type_cls = change_type_cls
    """
    change_type command of pressure_far_field.
    """
    child_object_type: pressure_far_field_child = pressure_far_field_child
    """
    child_object_type of pressure_far_field.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class statistics_shear_stress(Boolean):
    """
    Enable/Disable statistics for flow shear stresses.
    """

    fluent_name = "statistics-shear-stress?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class dt_init_limit(Real):
    """
    Set maximum value for pseudo time step size during first iteration.
    """

    fluent_name = "dt-init-limit"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class post_iter_per_time_step_count(Integer):
    """
    Set Number of post-processing iterations per time step.
    """

    fluent_name = "post-iter-per-time-step-count"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class reset_defined_derived_quantities(Boolean):
    """
    'reset_defined_derived_quantities' child.
    """

    fluent_name = "reset-defined-derived-quantities?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_6 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .open_channel import open_channel as open_channel_cls
from .inlet_number import inlet_number as inlet_number_cls
from .phase_spec import phase_spec as phase_spec_cls
from .frame_of_reference import frame_of_reference as frame_of_reference_cls
from .p0 import p0 as p0_cls
from .supersonic_or_initial_gauge_pressure import supersonic_or_initial_gauge_pressure as supersonic_or_initial_gauge_pressure_cls
from .t0 import t0 as t0_cls
from .direction_spec import direction_spec as direction_spec_cls
from .flow_spec import flow_spec as flow_spec_cls
from .ht_local import ht_local as ht_local_cls
from .ht_total import ht_total as ht_total_cls
from .vmag import vmag as vmag_cls
from .ht_bottom import ht_bottom as ht_bottom_cls
from .den_spec import den_spec as den_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction_component import flow_direction_component as flow_direction_component_cls
from .direction_vector_components import direction_vector_components as direction_vector_components_cls
from .axis_direction_component_1 import axis_direction_component as axis_direction_component_cls
from .axis_origin_component_1 import axis_origin_component as axis_origin_component_cls
from .les_spec_name import les_spec_name as les_spec_name_cls
from .rfg_number_of_modes import rfg_number_of_modes as rfg_number_of_modes_cls
from .vm_number_of_vortices import vm_number_of_vortices as vm_number_of_vortices_cls
from .vm_streamwise_fluct import vm_streamwise_fluct as vm_streamwise_fluct_cls
from .vm_mass_conservation import vm_mass_conservation as vm_mass_conservation_cls
from .volumetric_synthetic_turbulence_generator import volumetric_synthetic_turbulence_generator as volumetric_synthetic_turbulence_generator_cls
from .volumetric_synthetic_turbulence_generator_option import volumetric_synthetic_turbulence_generator_option as volumetric_synthetic_turbulence_generator_option_cls
from .volumetric_synthetic_turbulence_generator_option_thickness import volumetric_synthetic_turbulence_generator_option_thickness as volumetric_synthetic_turbulence_generator_option_thickness_cls
from .prevent_reverse_flow import prevent_reverse_flow as prevent_reverse_flow_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .granular_temperature import granular_temperature as granular_temperature_cls
from .iac import iac as iac_cls
from .lsfun import lsfun as lsfun_cls
from .volume_fraction import volume_fraction as volume_fraction_cls
from .species_in_mole_fractions import species_in_mole_fractions as species_in_mole_fractions_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .prob_mode_1 import prob_mode_1 as prob_mode_1_cls
from .prob_mode_2 import prob_mode_2 as prob_mode_2_cls
from .prob_mode_3 import prob_mode_3 as prob_mode_3_cls
from .equ_required import equ_required as equ_required_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .pb_disc_bc import pb_disc_bc as pb_disc_bc_cls
from .pb_disc import pb_disc as pb_disc_cls
from .pb_qmom_bc import pb_qmom_bc as pb_qmom_bc_cls
from .pb_qmom import pb_qmom as pb_qmom_cls
from .pb_smm_bc import pb_smm_bc as pb_smm_bc_cls
from .pb_smm import pb_smm as pb_smm_cls
from .pb_dqmom_bc import pb_dqmom_bc as pb_dqmom_bc_cls
from .pb_dqmom import pb_dqmom as pb_dqmom_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction_component import radial_direction_component as radial_direction_component_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .fmean import fmean as fmean_cls
from .fvar import fvar as fvar_cls
from .fmean2 import fmean2 as fmean2_cls
from .fvar2 import fvar2 as fvar2_cls
from .premixc import premixc as premixc_cls
from .premixc_var import premixc_var as premixc_var_cls
from .ecfm_sigma import ecfm_sigma as ecfm_sigma_cls
from .inert import inert as inert_cls
from .pollut_no import pollut_no as pollut_no_cls
from .pollut_hcn import pollut_hcn as pollut_hcn_cls
from .pollut_nh3 import pollut_nh3 as pollut_nh3_cls
from .pollut_n2o import pollut_n2o as pollut_n2o_cls
from .pollut_urea import pollut_urea as pollut_urea_cls
from .pollut_hnco import pollut_hnco as pollut_hnco_cls
from .pollut_nco import pollut_nco as pollut_nco_cls
from .pollut_so2 import pollut_so2 as pollut_so2_cls
from .pollut_h2s import pollut_h2s as pollut_h2s_cls
from .pollut_so3 import pollut_so3 as pollut_so3_cls
from .pollut_sh import pollut_sh as pollut_sh_cls
from .pollut_so import pollut_so as pollut_so_cls
from .pollut_soot import pollut_soot as pollut_soot_cls
from .pollut_nuclei import pollut_nuclei as pollut_nuclei_cls
from .pollut_ctar import pollut_ctar as pollut_ctar_cls
from .pollut_hg import pollut_hg as pollut_hg_cls
from .pollut_hgcl2 import pollut_hgcl2 as pollut_hgcl2_cls
from .pollut_hcl import pollut_hcl as pollut_hcl_cls
from .pollut_hgo import pollut_hgo as pollut_hgo_cls
from .pollut_cl import pollut_cl as pollut_cl_cls
from .pollut_cl2 import pollut_cl2 as pollut_cl2_cls
from .pollut_hgcl import pollut_hgcl as pollut_hgcl_cls
from .pollut_hocl import pollut_hocl as pollut_hocl_cls
from .tss_scalar import tss_scalar as tss_scalar_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .fensapice_drop_bccustom import fensapice_drop_bccustom as fensapice_drop_bccustom_cls
from .fensapice_drop_lwc import fensapice_drop_lwc as fensapice_drop_lwc_cls
from .fensapice_drop_dtemp import fensapice_drop_dtemp as fensapice_drop_dtemp_cls
from .fensapice_drop_ddiam import fensapice_drop_ddiam as fensapice_drop_ddiam_cls
from .fensapice_drop_dv import fensapice_drop_dv as fensapice_drop_dv_cls
from .fensapice_drop_dx import fensapice_drop_dx as fensapice_drop_dx_cls
from .fensapice_drop_dy import fensapice_drop_dy as fensapice_drop_dy_cls
from .fensapice_drop_dz import fensapice_drop_dz as fensapice_drop_dz_cls
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection as fensapice_dpm_surface_injection_cls
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream as fensapice_dpm_inj_nstream_cls
from .fensapice_drop_icc import fensapice_drop_icc as fensapice_drop_icc_cls
from .fensapice_drop_ctemp import fensapice_drop_ctemp as fensapice_drop_ctemp_cls
from .fensapice_drop_cdiam import fensapice_drop_cdiam as fensapice_drop_cdiam_cls
from .fensapice_drop_cv import fensapice_drop_cv as fensapice_drop_cv_cls
from .fensapice_drop_cx import fensapice_drop_cx as fensapice_drop_cx_cls
from .fensapice_drop_cy import fensapice_drop_cy as fensapice_drop_cy_cls
from .fensapice_drop_cz import fensapice_drop_cz as fensapice_drop_cz_cls
from .fensapice_drop_vrh import fensapice_drop_vrh as fensapice_drop_vrh_cls
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1 as fensapice_drop_vrh_1_cls
from .fensapice_drop_vc import fensapice_drop_vc as fensapice_drop_vc_cls
from .mixing_plane_thread import mixing_plane_thread as mixing_plane_thread_cls
from .wsf import wsf as wsf_cls
from .wsb import wsb as wsb_cls
from .wsn import wsn as wsn_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
from .ac_options import ac_options as ac_options_cls
from .impedance_0 import impedance_0 as impedance_0_cls
from .impedance_1 import impedance_1 as impedance_1_cls
from .impedance_2 import impedance_2 as impedance_2_cls
from .ac_wave import ac_wave as ac_wave_cls
from .les_spec import les_spec as les_spec_cls
from .a import a as a_cls
from .swirl_model import swirl_model as swirl_model_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .fan_omega import fan_omega as fan_omega_cls
from .fan_origin_components import fan_origin_components as fan_origin_components_cls
from .strength import strength as strength_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls
class intake_fan_child(Group):
    """
    'child_object_type' of intake_fan.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'open_channel',
         'inlet_number', 'phase_spec', 'frame_of_reference', 'p0',
         'supersonic_or_initial_gauge_pressure', 't0', 'direction_spec',
         'flow_spec', 'ht_local', 'ht_total', 'vmag', 'ht_bottom', 'den_spec',
         'coordinate_system', 'flow_direction_component',
         'direction_vector_components', 'axis_direction_component',
         'axis_origin_component', 'les_spec_name', 'rfg_number_of_modes',
         'vm_number_of_vortices', 'vm_streamwise_fluct',
         'vm_mass_conservation', 'volumetric_synthetic_turbulence_generator',
         'volumetric_synthetic_turbulence_generator_option',
         'volumetric_synthetic_turbulence_generator_option_thickness',
         'prevent_reverse_flow', 'ke_spec', 'nut', 'kl', 'intermit', 'k', 'e',
         'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'granular_temperature', 'iac', 'lsfun', 'volume_fraction',
         'species_in_mole_fractions', 'mf', 'elec_potential_type',
         'potential_value', 'dual_potential_type', 'dual_potential_value',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'equ_required', 'uds_bc', 'uds', 'pb_disc_bc', 'pb_disc',
         'pb_qmom_bc', 'pb_qmom', 'pb_smm_bc', 'pb_smm', 'pb_dqmom_bc',
         'pb_dqmom', 'radiation_bc', 'radial_direction_component',
         'coll_dtheta', 'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'fmean', 'fvar', 'fmean2',
         'fvar2', 'premixc', 'premixc_var', 'ecfm_sigma', 'inert',
         'pollut_no', 'pollut_hcn', 'pollut_nh3', 'pollut_n2o', 'pollut_urea',
         'pollut_hnco', 'pollut_nco', 'pollut_so2', 'pollut_h2s',
         'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'tss_scalar', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'fensapice_flow_bc_subtype', 'fensapice_drop_bccustom',
         'fensapice_drop_lwc', 'fensapice_drop_dtemp', 'fensapice_drop_ddiam',
         'fensapice_drop_dv', 'fensapice_drop_dx', 'fensapice_drop_dy',
         'fensapice_drop_dz', 'fensapice_dpm_surface_injection',
         'fensapice_dpm_inj_nstream', 'fensapice_drop_icc',
         'fensapice_drop_ctemp', 'fensapice_drop_cdiam', 'fensapice_drop_cv',
         'fensapice_drop_cx', 'fensapice_drop_cy', 'fensapice_drop_cz',
         'fensapice_drop_vrh', 'fensapice_drop_vrh_1', 'fensapice_drop_vc',
         'mixing_plane_thread', 'wsf', 'wsb', 'wsn', 'solar_fluxes',
         'solar_shining_factor', 'radiating_s2s_surface', 'ac_options',
         'impedance_0', 'impedance_1', 'impedance_2', 'ac_wave', 'les_spec',
         'a', 'swirl_model', 'swirl_factor', 'fan_omega',
         'fan_origin_components', 'strength', 'new_fan_definition']

    phase: phase_cls = phase_cls
    """
    phase child of intake_fan_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of intake_fan_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of intake_fan_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of intake_fan_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of intake_fan_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of intake_fan_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of intake_fan_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of intake_fan_child.
    """
    open_channel: open_channel_cls = open_channel_cls
    """
    open_channel child of intake_fan_child.
    """
    inlet_number: inlet_number_cls = inlet_number_cls
    """
    inlet_number child of intake_fan_child.
    """
    phase_spec: phase_spec_cls = phase_spec_cls
    """
    phase_spec child of intake_fan_child.
    """
    frame_of_reference: frame_of_reference_cls = frame_of_reference_cls
    """
    frame_of_reference child of intake_fan_child.
    """
    p0: p0_cls = p0_cls
    """
    p0 child of intake_fan_child.
    """
    supersonic_or_initial_gauge_pressure: supersonic_or_initial_gauge_pressure_cls = supersonic_or_initial_gauge_pressure_cls
    """
    supersonic_or_initial_gauge_pressure child of intake_fan_child.
    """
    t0: t0_cls = t0_cls
    """
    t0 child of intake_fan_child.
    """
    direction_spec: direction_spec_cls = direction_spec_cls
    """
    direction_spec child of intake_fan_child.
    """
    flow_spec: flow_spec_cls = flow_spec_cls
    """
    flow_spec child of intake_fan_child.
    """
    ht_local: ht_local_cls = ht_local_cls
    """
    ht_local child of intake_fan_child.
    """
    ht_total: ht_total_cls = ht_total_cls
    """
    ht_total child of intake_fan_child.
    """
    vmag: vmag_cls = vmag_cls
    """
    vmag child of intake_fan_child.
    """
    ht_bottom: ht_bottom_cls = ht_bottom_cls
    """
    ht_bottom child of intake_fan_child.
    """
    den_spec: den_spec_cls = den_spec_cls
    """
    den_spec child of intake_fan_child.
    """
    coordinate_system: coordinate_system_cls = coordinate_system_cls
    """
    coordinate_system child of intake_fan_child.
    """
    flow_direction_component: flow_direction_component_cls = flow_direction_component_cls
    """
    flow_direction_component child of intake_fan_child.
    """
    direction_vector_components: direction_vector_components_cls = direction_vector_components_cls
    """
    direction_vector_components child of intake_fan_child.
    """
    axis_direction_component: axis_direction_component_cls = axis_direction_component_cls
    """
    axis_direction_component child of intake_fan_child.
    """
    axis_origin_component: axis_origin_component_cls = axis_origin_component_cls
    """
    axis_origin_component child of intake_fan_child.
    """
    les_spec_name: les_spec_name_cls = les_spec_name_cls
    """
    les_spec_name child of intake_fan_child.
    """
    rfg_number_of_modes: rfg_number_of_modes_cls = rfg_number_of_modes_cls
    """
    rfg_number_of_modes child of intake_fan_child.
    """
    vm_number_of_vortices: vm_number_of_vortices_cls = vm_number_of_vortices_cls
    """
    vm_number_of_vortices child of intake_fan_child.
    """
    vm_streamwise_fluct: vm_streamwise_fluct_cls = vm_streamwise_fluct_cls
    """
    vm_streamwise_fluct child of intake_fan_child.
    """
    vm_mass_conservation: vm_mass_conservation_cls = vm_mass_conservation_cls
    """
    vm_mass_conservation child of intake_fan_child.
    """
    volumetric_synthetic_turbulence_generator: volumetric_synthetic_turbulence_generator_cls = volumetric_synthetic_turbulence_generator_cls
    """
    volumetric_synthetic_turbulence_generator child of intake_fan_child.
    """
    volumetric_synthetic_turbulence_generator_option: volumetric_synthetic_turbulence_generator_option_cls = volumetric_synthetic_turbulence_generator_option_cls
    """
    volumetric_synthetic_turbulence_generator_option child of intake_fan_child.
    """
    volumetric_synthetic_turbulence_generator_option_thickness: volumetric_synthetic_turbulence_generator_option_thickness_cls = volumetric_synthetic_turbulence_generator_option_thickness_cls
    """
    volumetric_synthetic_turbulence_generator_option_thickness child of intake_fan_child.
    """
    prevent_reverse_flow: prevent_reverse_flow_cls = prevent_reverse_flow_cls
    """
    prevent_reverse_flow child of intake_fan_child.
    """
    ke_spec: ke_spec_cls = ke_spec_cls
    """
    ke_spec child of intake_fan_child.
    """
    nut: nut_cls = nut_cls
    """
    nut child of intake_fan_child.
    """
    kl: kl_cls = kl_cls
    """
    kl child of intake_fan_child.
    """
    intermit: intermit_cls = intermit_cls
    """
    intermit child of intake_fan_child.
    """
    k: k_cls = k_cls
    """
    k child of intake_fan_child.
    """
    e: e_cls = e_cls
    """
    e child of intake_fan_child.
    """
    o: o_cls = o_cls
    """
    o child of intake_fan_child.
    """
    v2: v2_cls = v2_cls
    """
    v2 child of intake_fan_child.
    """
    turb_intensity: turb_intensity_cls = turb_intensity_cls
    """
    turb_intensity child of intake_fan_child.
    """
    turb_length_scale: turb_length_scale_cls = turb_length_scale_cls
    """
    turb_length_scale child of intake_fan_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam_cls = turb_hydraulic_diam_cls
    """
    turb_hydraulic_diam child of intake_fan_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio_cls = turb_viscosity_ratio_cls
    """
    turb_viscosity_ratio child of intake_fan_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile_cls = turb_viscosity_ratio_profile_cls
    """
    turb_viscosity_ratio_profile child of intake_fan_child.
    """
    rst_spec: rst_spec_cls = rst_spec_cls
    """
    rst_spec child of intake_fan_child.
    """
    uu: uu_cls = uu_cls
    """
    uu child of intake_fan_child.
    """
    vv: vv_cls = vv_cls
    """
    vv child of intake_fan_child.
    """
    ww: ww_cls = ww_cls
    """
    ww child of intake_fan_child.
    """
    uv: uv_cls = uv_cls
    """
    uv child of intake_fan_child.
    """
    vw: vw_cls = vw_cls
    """
    vw child of intake_fan_child.
    """
    uw: uw_cls = uw_cls
    """
    uw child of intake_fan_child.
    """
    ksgs_spec: ksgs_spec_cls = ksgs_spec_cls
    """
    ksgs_spec child of intake_fan_child.
    """
    ksgs: ksgs_cls = ksgs_cls
    """
    ksgs child of intake_fan_child.
    """
    sgs_turb_intensity: sgs_turb_intensity_cls = sgs_turb_intensity_cls
    """
    sgs_turb_intensity child of intake_fan_child.
    """
    granular_temperature: granular_temperature_cls = granular_temperature_cls
    """
    granular_temperature child of intake_fan_child.
    """
    iac: iac_cls = iac_cls
    """
    iac child of intake_fan_child.
    """
    lsfun: lsfun_cls = lsfun_cls
    """
    lsfun child of intake_fan_child.
    """
    volume_fraction: volume_fraction_cls = volume_fraction_cls
    """
    volume_fraction child of intake_fan_child.
    """
    species_in_mole_fractions: species_in_mole_fractions_cls = species_in_mole_fractions_cls
    """
    species_in_mole_fractions child of intake_fan_child.
    """
    mf: mf_cls = mf_cls
    """
    mf child of intake_fan_child.
    """
    elec_potential_type: elec_potential_type_cls = elec_potential_type_cls
    """
    elec_potential_type child of intake_fan_child.
    """
    potential_value: potential_value_cls = potential_value_cls
    """
    potential_value child of intake_fan_child.
    """
    dual_potential_type: dual_potential_type_cls = dual_potential_type_cls
    """
    dual_potential_type child of intake_fan_child.
    """
    dual_potential_value: dual_potential_value_cls = dual_potential_value_cls
    """
    dual_potential_value child of intake_fan_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of intake_fan_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of intake_fan_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of intake_fan_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of intake_fan_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of intake_fan_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of intake_fan_child.
    """
    prob_mode_1: prob_mode_1_cls = prob_mode_1_cls
    """
    prob_mode_1 child of intake_fan_child.
    """
    prob_mode_2: prob_mode_2_cls = prob_mode_2_cls
    """
    prob_mode_2 child of intake_fan_child.
    """
    prob_mode_3: prob_mode_3_cls = prob_mode_3_cls
    """
    prob_mode_3 child of intake_fan_child.
    """
    equ_required: equ_required_cls = equ_required_cls
    """
    equ_required child of intake_fan_child.
    """
    uds_bc: uds_bc_cls = uds_bc_cls
    """
    uds_bc child of intake_fan_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of intake_fan_child.
    """
    pb_disc_bc: pb_disc_bc_cls = pb_disc_bc_cls
    """
    pb_disc_bc child of intake_fan_child.
    """
    pb_disc: pb_disc_cls = pb_disc_cls
    """
    pb_disc child of intake_fan_child.
    """
    pb_qmom_bc: pb_qmom_bc_cls = pb_qmom_bc_cls
    """
    pb_qmom_bc child of intake_fan_child.
    """
    pb_qmom: pb_qmom_cls = pb_qmom_cls
    """
    pb_qmom child of intake_fan_child.
    """
    pb_smm_bc: pb_smm_bc_cls = pb_smm_bc_cls
    """
    pb_smm_bc child of intake_fan_child.
    """
    pb_smm: pb_smm_cls = pb_smm_cls
    """
    pb_smm child of intake_fan_child.
    """
    pb_dqmom_bc: pb_dqmom_bc_cls = pb_dqmom_bc_cls
    """
    pb_dqmom_bc child of intake_fan_child.
    """
    pb_dqmom: pb_dqmom_cls = pb_dqmom_cls
    """
    pb_dqmom child of intake_fan_child.
    """
    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of intake_fan_child.
    """
    radial_direction_component: radial_direction_component_cls = radial_direction_component_cls
    """
    radial_direction_component child of intake_fan_child.
    """
    coll_dtheta: coll_dtheta_cls = coll_dtheta_cls
    """
    coll_dtheta child of intake_fan_child.
    """
    coll_dphi: coll_dphi_cls = coll_dphi_cls
    """
    coll_dphi child of intake_fan_child.
    """
    band_q_irrad: band_q_irrad_cls = band_q_irrad_cls
    """
    band_q_irrad child of intake_fan_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse_cls = band_q_irrad_diffuse_cls
    """
    band_q_irrad_diffuse child of intake_fan_child.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of intake_fan_child.
    """
    solar_direction: solar_direction_cls = solar_direction_cls
    """
    solar_direction child of intake_fan_child.
    """
    solar_irradiation: solar_irradiation_cls = solar_irradiation_cls
    """
    solar_irradiation child of intake_fan_child.
    """
    t_b_b_spec: t_b_b_spec_cls = t_b_b_spec_cls
    """
    t_b_b_spec child of intake_fan_child.
    """
    t_b_b: t_b_b_cls = t_b_b_cls
    """
    t_b_b child of intake_fan_child.
    """
    in_emiss: in_emiss_cls = in_emiss_cls
    """
    in_emiss child of intake_fan_child.
    """
    fmean: fmean_cls = fmean_cls
    """
    fmean child of intake_fan_child.
    """
    fvar: fvar_cls = fvar_cls
    """
    fvar child of intake_fan_child.
    """
    fmean2: fmean2_cls = fmean2_cls
    """
    fmean2 child of intake_fan_child.
    """
    fvar2: fvar2_cls = fvar2_cls
    """
    fvar2 child of intake_fan_child.
    """
    premixc: premixc_cls = premixc_cls
    """
    premixc child of intake_fan_child.
    """
    premixc_var: premixc_var_cls = premixc_var_cls
    """
    premixc_var child of intake_fan_child.
    """
    ecfm_sigma: ecfm_sigma_cls = ecfm_sigma_cls
    """
    ecfm_sigma child of intake_fan_child.
    """
    inert: inert_cls = inert_cls
    """
    inert child of intake_fan_child.
    """
    pollut_no: pollut_no_cls = pollut_no_cls
    """
    pollut_no child of intake_fan_child.
    """
    pollut_hcn: pollut_hcn_cls = pollut_hcn_cls
    """
    pollut_hcn child of intake_fan_child.
    """
    pollut_nh3: pollut_nh3_cls = pollut_nh3_cls
    """
    pollut_nh3 child of intake_fan_child.
    """
    pollut_n2o: pollut_n2o_cls = pollut_n2o_cls
    """
    pollut_n2o child of intake_fan_child.
    """
    pollut_urea: pollut_urea_cls = pollut_urea_cls
    """
    pollut_urea child of intake_fan_child.
    """
    pollut_hnco: pollut_hnco_cls = pollut_hnco_cls
    """
    pollut_hnco child of intake_fan_child.
    """
    pollut_nco: pollut_nco_cls = pollut_nco_cls
    """
    pollut_nco child of intake_fan_child.
    """
    pollut_so2: pollut_so2_cls = pollut_so2_cls
    """
    pollut_so2 child of intake_fan_child.
    """
    pollut_h2s: pollut_h2s_cls = pollut_h2s_cls
    """
    pollut_h2s child of intake_fan_child.
    """
    pollut_so3: pollut_so3_cls = pollut_so3_cls
    """
    pollut_so3 child of intake_fan_child.
    """
    pollut_sh: pollut_sh_cls = pollut_sh_cls
    """
    pollut_sh child of intake_fan_child.
    """
    pollut_so: pollut_so_cls = pollut_so_cls
    """
    pollut_so child of intake_fan_child.
    """
    pollut_soot: pollut_soot_cls = pollut_soot_cls
    """
    pollut_soot child of intake_fan_child.
    """
    pollut_nuclei: pollut_nuclei_cls = pollut_nuclei_cls
    """
    pollut_nuclei child of intake_fan_child.
    """
    pollut_ctar: pollut_ctar_cls = pollut_ctar_cls
    """
    pollut_ctar child of intake_fan_child.
    """
    pollut_hg: pollut_hg_cls = pollut_hg_cls
    """
    pollut_hg child of intake_fan_child.
    """
    pollut_hgcl2: pollut_hgcl2_cls = pollut_hgcl2_cls
    """
    pollut_hgcl2 child of intake_fan_child.
    """
    pollut_hcl: pollut_hcl_cls = pollut_hcl_cls
    """
    pollut_hcl child of intake_fan_child.
    """
    pollut_hgo: pollut_hgo_cls = pollut_hgo_cls
    """
    pollut_hgo child of intake_fan_child.
    """
    pollut_cl: pollut_cl_cls = pollut_cl_cls
    """
    pollut_cl child of intake_fan_child.
    """
    pollut_cl2: pollut_cl2_cls = pollut_cl2_cls
    """
    pollut_cl2 child of intake_fan_child.
    """
    pollut_hgcl: pollut_hgcl_cls = pollut_hgcl_cls
    """
    pollut_hgcl child of intake_fan_child.
    """
    pollut_hocl: pollut_hocl_cls = pollut_hocl_cls
    """
    pollut_hocl child of intake_fan_child.
    """
    tss_scalar: tss_scalar_cls = tss_scalar_cls
    """
    tss_scalar child of intake_fan_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of intake_fan_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of intake_fan_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of intake_fan_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of intake_fan_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype_cls = fensapice_flow_bc_subtype_cls
    """
    fensapice_flow_bc_subtype child of intake_fan_child.
    """
    fensapice_drop_bccustom: fensapice_drop_bccustom_cls = fensapice_drop_bccustom_cls
    """
    fensapice_drop_bccustom child of intake_fan_child.
    """
    fensapice_drop_lwc: fensapice_drop_lwc_cls = fensapice_drop_lwc_cls
    """
    fensapice_drop_lwc child of intake_fan_child.
    """
    fensapice_drop_dtemp: fensapice_drop_dtemp_cls = fensapice_drop_dtemp_cls
    """
    fensapice_drop_dtemp child of intake_fan_child.
    """
    fensapice_drop_ddiam: fensapice_drop_ddiam_cls = fensapice_drop_ddiam_cls
    """
    fensapice_drop_ddiam child of intake_fan_child.
    """
    fensapice_drop_dv: fensapice_drop_dv_cls = fensapice_drop_dv_cls
    """
    fensapice_drop_dv child of intake_fan_child.
    """
    fensapice_drop_dx: fensapice_drop_dx_cls = fensapice_drop_dx_cls
    """
    fensapice_drop_dx child of intake_fan_child.
    """
    fensapice_drop_dy: fensapice_drop_dy_cls = fensapice_drop_dy_cls
    """
    fensapice_drop_dy child of intake_fan_child.
    """
    fensapice_drop_dz: fensapice_drop_dz_cls = fensapice_drop_dz_cls
    """
    fensapice_drop_dz child of intake_fan_child.
    """
    fensapice_dpm_surface_injection: fensapice_dpm_surface_injection_cls = fensapice_dpm_surface_injection_cls
    """
    fensapice_dpm_surface_injection child of intake_fan_child.
    """
    fensapice_dpm_inj_nstream: fensapice_dpm_inj_nstream_cls = fensapice_dpm_inj_nstream_cls
    """
    fensapice_dpm_inj_nstream child of intake_fan_child.
    """
    fensapice_drop_icc: fensapice_drop_icc_cls = fensapice_drop_icc_cls
    """
    fensapice_drop_icc child of intake_fan_child.
    """
    fensapice_drop_ctemp: fensapice_drop_ctemp_cls = fensapice_drop_ctemp_cls
    """
    fensapice_drop_ctemp child of intake_fan_child.
    """
    fensapice_drop_cdiam: fensapice_drop_cdiam_cls = fensapice_drop_cdiam_cls
    """
    fensapice_drop_cdiam child of intake_fan_child.
    """
    fensapice_drop_cv: fensapice_drop_cv_cls = fensapice_drop_cv_cls
    """
    fensapice_drop_cv child of intake_fan_child.
    """
    fensapice_drop_cx: fensapice_drop_cx_cls = fensapice_drop_cx_cls
    """
    fensapice_drop_cx child of intake_fan_child.
    """
    fensapice_drop_cy: fensapice_drop_cy_cls = fensapice_drop_cy_cls
    """
    fensapice_drop_cy child of intake_fan_child.
    """
    fensapice_drop_cz: fensapice_drop_cz_cls = fensapice_drop_cz_cls
    """
    fensapice_drop_cz child of intake_fan_child.
    """
    fensapice_drop_vrh: fensapice_drop_vrh_cls = fensapice_drop_vrh_cls
    """
    fensapice_drop_vrh child of intake_fan_child.
    """
    fensapice_drop_vrh_1: fensapice_drop_vrh_1_cls = fensapice_drop_vrh_1_cls
    """
    fensapice_drop_vrh_1 child of intake_fan_child.
    """
    fensapice_drop_vc: fensapice_drop_vc_cls = fensapice_drop_vc_cls
    """
    fensapice_drop_vc child of intake_fan_child.
    """
    mixing_plane_thread: mixing_plane_thread_cls = mixing_plane_thread_cls
    """
    mixing_plane_thread child of intake_fan_child.
    """
    wsf: wsf_cls = wsf_cls
    """
    wsf child of intake_fan_child.
    """
    wsb: wsb_cls = wsb_cls
    """
    wsb child of intake_fan_child.
    """
    wsn: wsn_cls = wsn_cls
    """
    wsn child of intake_fan_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of intake_fan_child.
    """
    solar_shining_factor: solar_shining_factor_cls = solar_shining_factor_cls
    """
    solar_shining_factor child of intake_fan_child.
    """
    radiating_s2s_surface: radiating_s2s_surface_cls = radiating_s2s_surface_cls
    """
    radiating_s2s_surface child of intake_fan_child.
    """
    ac_options: ac_options_cls = ac_options_cls
    """
    ac_options child of intake_fan_child.
    """
    impedance_0: impedance_0_cls = impedance_0_cls
    """
    impedance_0 child of intake_fan_child.
    """
    impedance_1: impedance_1_cls = impedance_1_cls
    """
    impedance_1 child of intake_fan_child.
    """
    impedance_2: impedance_2_cls = impedance_2_cls
    """
    impedance_2 child of intake_fan_child.
    """
    ac_wave: ac_wave_cls = ac_wave_cls
    """
    ac_wave child of intake_fan_child.
    """
    les_spec: les_spec_cls = les_spec_cls
    """
    les_spec child of intake_fan_child.
    """
    a: a_cls = a_cls
    """
    a child of intake_fan_child.
    """
    swirl_model: swirl_model_cls = swirl_model_cls
    """
    swirl_model child of intake_fan_child.
    """
    swirl_factor: swirl_factor_cls = swirl_factor_cls
    """
    swirl_factor child of intake_fan_child.
    """
    fan_omega: fan_omega_cls = fan_omega_cls
    """
    fan_omega child of intake_fan_child.
    """
    fan_origin_components: fan_origin_components_cls = fan_origin_components_cls
    """
    fan_origin_components child of intake_fan_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of intake_fan_child.
    """
    new_fan_definition: new_fan_definition_cls = new_fan_definition_cls
    """
    new_fan_definition child of intake_fan_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .diffusion_controlled import diffusion_controlled as diffusion_controlled_cls
from .convection_diffusion_controlled import convection_diffusion_controlled as convection_diffusion_controlled_cls
class vaporization_model(Group):
    """
    'vaporization_model' child.
    """

    fluent_name = "vaporization-model"

    child_names = \
        ['option', 'diffusion_controlled', 'convection_diffusion_controlled']

    option: option_cls = option_cls
    """
    option child of vaporization_model.
    """
    diffusion_controlled: diffusion_controlled_cls = diffusion_controlled_cls
    """
    diffusion_controlled child of vaporization_model.
    """
    convection_diffusion_controlled: convection_diffusion_controlled_cls = convection_diffusion_controlled_cls
    """
    convection_diffusion_controlled child of vaporization_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class reporting_interval(Integer):
    """
    Set number of solver iterations before returning to scheme.
    """

    fluent_name = "reporting-interval"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class default_min_max_relaxation_limits(Boolean):
    """
    'default_min_max_relaxation_limits' child.
    """

    fluent_name = "default-min-max-relaxation-limits?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class ablation_select_model(String, _HasAllowedValuesMixin):
    """
    'ablation_select_model' child.
    """

    fluent_name = "ablation-select-model"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class data_frequency(Real):
    """
    Set the iteration or time step increment for saving data files.
    """

    fluent_name = "data-frequency"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class beach_damp_len_spec(String, _HasAllowedValuesMixin):
    """
    'beach_damp_len_spec' child.
    """

    fluent_name = "beach-damp-len-spec"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class splashing_distribution_function(String, _HasAllowedValuesMixin):
    """
    Specify the name of the splashing distribution function.
    """

    fluent_name = "splashing-distribution-function"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class beams:
    fluent_name = ...
    command_names = ...

    def copy(self, orig_beam_name: str, beam_name: str, ap_face_zone: str, beam_length: Union[float, str], ray_npoints: int, x_beam_vector: Union[float, str], y_beam_vector: Union[float, str], z_beam_vector: Union[float, str]):
        """
        Copy optical beam grid.
        
        Parameters
        ----------
            orig_beam_name : str
                Choose the name for the optical beam to be copied.
            beam_name : str
                Set a unique name for each optical beam.
            ap_face_zone : str
                Set the wall face zones to specify the optical aperture surface.
            beam_length : real
                Set the length of optical beam propagation.
            ray_npoints : int
                Set the number of grid point in each ray of the optical beam.
            x_beam_vector : real
                Set the x-component of the beam propagation vector.
            y_beam_vector : real
                Set the y-component of the beam propagation vector.
            z_beam_vector : real
                Set the z-component of the beam propagation vector.
        
        """

    def list_beam_parameters(self, beam_name: str):
        """
        List parameters of optical beam grid.
        
        Parameters
        ----------
            beam_name : str
                Choose the name for the optical beam to be listed.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class diameter_statistics(Boolean):
    """
    Compute Rosin Rammler parameters, Sauter and other mean diameters.
    Requires specification of diameter as sampling variable.
    """

    fluent_name = "diameter-statistics?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .cell_func_domain_export import cell_func_domain_export as cell_func_domain_export_cls
class ensight_gold(Command):
    """
    Write EnSight Gold geometry, velocity, and scalar files.
    
    Parameters
    ----------
        name : str
            'name' child.
        cell_func_domain_export : typing.List[str]
            'cell_func_domain_export' child.
    
    """

    fluent_name = "ensight-gold"

    argument_names = \
        ['name', 'cell_func_domain_export']

    name: name_cls = name_cls
    """
    name argument of ensight_gold.
    """
    cell_func_domain_export: cell_func_domain_export_cls = cell_func_domain_export_cls
    """
    cell_func_domain_export argument of ensight_gold.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class re_randomize_every_iteration(Boolean):
    """
    Enable/disable changing the pseudo-random number sequences from iteration to iteration.
    """

    fluent_name = "re-randomize-every-iteration?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase import phase as phase_cls
from .name_1 import name as name_cls
from .material import material as material_cls
from .sources import sources as sources_cls
from .source_terms_1 import source_terms as source_terms_cls
from .fixed import fixed as fixed_cls
from .cylindrical_fixed_var import cylindrical_fixed_var as cylindrical_fixed_var_cls
from .fixes import fixes as fixes_cls
from .motion_spec import motion_spec as motion_spec_cls
from .relative_to_thread import relative_to_thread as relative_to_thread_cls
from .omega import omega as omega_cls
from .axis_origin_1 import axis_origin as axis_origin_cls
from .axis_direction_1 import axis_direction as axis_direction_cls
from .udf_zmotion_name import udf_zmotion_name as udf_zmotion_name_cls
from .mrf_motion import mrf_motion as mrf_motion_cls
from .mrf_relative_to_thread import mrf_relative_to_thread as mrf_relative_to_thread_cls
from .mrf_omega import mrf_omega as mrf_omega_cls
from .reference_frame_velocity import reference_frame_velocity as reference_frame_velocity_cls
from .reference_frame_axis_origin import reference_frame_axis_origin as reference_frame_axis_origin_cls
from .reference_frame_axis_direction import reference_frame_axis_direction as reference_frame_axis_direction_cls
from .mrf_udf_zmotion_name import mrf_udf_zmotion_name as mrf_udf_zmotion_name_cls
from .mgrid_enable_transient import mgrid_enable_transient as mgrid_enable_transient_cls
from .mgrid_motion import mgrid_motion as mgrid_motion_cls
from .mgrid_relative_to_thread import mgrid_relative_to_thread as mgrid_relative_to_thread_cls
from .mgrid_omega import mgrid_omega as mgrid_omega_cls
from .moving_mesh_velocity import moving_mesh_velocity as moving_mesh_velocity_cls
from .moving_mesh_axis_origin import moving_mesh_axis_origin as moving_mesh_axis_origin_cls
from .moving_mesh_axis_direction import moving_mesh_axis_direction as moving_mesh_axis_direction_cls
from .mgrid_udf_zmotion_name import mgrid_udf_zmotion_name as mgrid_udf_zmotion_name_cls
from .solid_motion import solid_motion as solid_motion_cls
from .solid_relative_to_thread import solid_relative_to_thread as solid_relative_to_thread_cls
from .solid_omega import solid_omega as solid_omega_cls
from .solid_motion_velocity import solid_motion_velocity as solid_motion_velocity_cls
from .solid_motion_axis_origin import solid_motion_axis_origin as solid_motion_axis_origin_cls
from .solid_motion_axis_direction import solid_motion_axis_direction as solid_motion_axis_direction_cls
from .solid_udf_zmotion_name import solid_udf_zmotion_name as solid_udf_zmotion_name_cls
from .radiating import radiating as radiating_cls
from .les_embedded import les_embedded as les_embedded_cls
from .contact_property import contact_property as contact_property_cls
from .active_wetsteam_zone import active_wetsteam_zone as active_wetsteam_zone_cls
from .vapor_phase_realgas import vapor_phase_realgas as vapor_phase_realgas_cls
from .laminar import laminar as laminar_cls
from .laminar_mut_zero import laminar_mut_zero as laminar_mut_zero_cls
from .les_embedded_spec import les_embedded_spec as les_embedded_spec_cls
from .les_embedded_mom_scheme import les_embedded_mom_scheme as les_embedded_mom_scheme_cls
from .les_embedded_c_wale import les_embedded_c_wale as les_embedded_c_wale_cls
from .les_embedded_c_smag import les_embedded_c_smag as les_embedded_c_smag_cls
from .glass import glass as glass_cls
from .porous import porous as porous_cls
from .conical import conical as conical_cls
from .dir_spec_cond import dir_spec_cond as dir_spec_cond_cls
from .cursys import cursys as cursys_cls
from .cursys_name import cursys_name as cursys_name_cls
from .direction_1_x import direction_1_x as direction_1_x_cls
from .direction_1_y import direction_1_y as direction_1_y_cls
from .direction_1_z import direction_1_z as direction_1_z_cls
from .direction_2_x import direction_2_x as direction_2_x_cls
from .direction_2_y import direction_2_y as direction_2_y_cls
from .direction_2_z import direction_2_z as direction_2_z_cls
from .cone_axis_x import cone_axis_x as cone_axis_x_cls
from .cone_axis_y import cone_axis_y as cone_axis_y_cls
from .cone_axis_z import cone_axis_z as cone_axis_z_cls
from .cone_axis_pt_x import cone_axis_pt_x as cone_axis_pt_x_cls
from .cone_axis_pt_y import cone_axis_pt_y as cone_axis_pt_y_cls
from .cone_axis_pt_z import cone_axis_pt_z as cone_axis_pt_z_cls
from .cone_angle import cone_angle as cone_angle_cls
from .rel_vel_resistance import rel_vel_resistance as rel_vel_resistance_cls
from .porous_r_1 import porous_r_1 as porous_r_1_cls
from .porous_r_2 import porous_r_2 as porous_r_2_cls
from .porous_r_3 import porous_r_3 as porous_r_3_cls
from .alt_inertial_form import alt_inertial_form as alt_inertial_form_cls
from .porous_c_1 import porous_c_1 as porous_c_1_cls
from .porous_c_2 import porous_c_2 as porous_c_2_cls
from .porous_c_3 import porous_c_3 as porous_c_3_cls
from .c0 import c0 as c0_cls
from .c1 import c1 as c1_cls
from .porosity import porosity as porosity_cls
from .viscosity_ratio import viscosity_ratio as viscosity_ratio_cls
from .none import none as none_cls
from .corey import corey as corey_cls
from .stone_1 import stone_1 as stone_1_cls
from .stone_2 import stone_2 as stone_2_cls
from .rel_perm_limit_p1 import rel_perm_limit_p1 as rel_perm_limit_p1_cls
from .rel_perm_limit_p2 import rel_perm_limit_p2 as rel_perm_limit_p2_cls
from .ref_perm_p1 import ref_perm_p1 as ref_perm_p1_cls
from .exp_p1 import exp_p1 as exp_p1_cls
from .res_sat_p1 import res_sat_p1 as res_sat_p1_cls
from .ref_perm_p2 import ref_perm_p2 as ref_perm_p2_cls
from .exp_p2 import exp_p2 as exp_p2_cls
from .res_sat_p2 import res_sat_p2 as res_sat_p2_cls
from .ref_perm_p3 import ref_perm_p3 as ref_perm_p3_cls
from .exp_p3 import exp_p3 as exp_p3_cls
from .res_sat_p3 import res_sat_p3 as res_sat_p3_cls
from .capillary_pressure import capillary_pressure as capillary_pressure_cls
from .max_capillary_pressure import max_capillary_pressure as max_capillary_pressure_cls
from .van_genuchten_pg import van_genuchten_pg as van_genuchten_pg_cls
from .van_genuchten_ng import van_genuchten_ng as van_genuchten_ng_cls
from .skjaeveland_nw_pc_coef import skjaeveland_nw_pc_coef as skjaeveland_nw_pc_coef_cls
from .skjaeveland_nw_pc_pwr import skjaeveland_nw_pc_pwr as skjaeveland_nw_pc_pwr_cls
from .skjaeveland_wet_pc_coef import skjaeveland_wet_pc_coef as skjaeveland_wet_pc_coef_cls
from .skjaeveland_wet_pc_pwr import skjaeveland_wet_pc_pwr as skjaeveland_wet_pc_pwr_cls
from .brooks_corey_pe import brooks_corey_pe as brooks_corey_pe_cls
from .brooks_corey_ng import brooks_corey_ng as brooks_corey_ng_cls
from .leverett_con_ang import leverett_con_ang as leverett_con_ang_cls
from .rel_perm_tabular_p1 import rel_perm_tabular_p1 as rel_perm_tabular_p1_cls
from .rel_perm_table_p1 import rel_perm_table_p1 as rel_perm_table_p1_cls
from .rel_perm_satw_p1 import rel_perm_satw_p1 as rel_perm_satw_p1_cls
from .rel_perm_rp_p1 import rel_perm_rp_p1 as rel_perm_rp_p1_cls
from .rel_perm_tabular_p2 import rel_perm_tabular_p2 as rel_perm_tabular_p2_cls
from .rel_perm_table_p2 import rel_perm_table_p2 as rel_perm_table_p2_cls
from .rel_perm_satw_p2 import rel_perm_satw_p2 as rel_perm_satw_p2_cls
from .rel_perm_rp_p2 import rel_perm_rp_p2 as rel_perm_rp_p2_cls
from .wetting_phase import wetting_phase as wetting_phase_cls
from .non_wetting_phase import non_wetting_phase as non_wetting_phase_cls
from .equib_thermal import equib_thermal as equib_thermal_cls
from .non_equib_thermal import non_equib_thermal as non_equib_thermal_cls
from .solid_material import solid_material as solid_material_cls
from .area_density import area_density as area_density_cls
from .heat_transfer_coeff import heat_transfer_coeff as heat_transfer_coeff_cls
from .fanzone import fanzone as fanzone_cls
from .fan_zone_list import fan_zone_list as fan_zone_list_cls
from .fan_thickness import fan_thickness as fan_thickness_cls
from .fan_hub_rad import fan_hub_rad as fan_hub_rad_cls
from .fan_tip_rad import fan_tip_rad as fan_tip_rad_cls
from .fan_x_origin import fan_x_origin as fan_x_origin_cls
from .fan_y_origin import fan_y_origin as fan_y_origin_cls
from .fan_z_origin import fan_z_origin as fan_z_origin_cls
from .fan_rot_dir import fan_rot_dir as fan_rot_dir_cls
from .fan_opert_angvel import fan_opert_angvel as fan_opert_angvel_cls
from .fan_inflection_point import fan_inflection_point as fan_inflection_point_cls
from .limit_flow_fan import limit_flow_fan as limit_flow_fan_cls
from .max_flow_rate import max_flow_rate as max_flow_rate_cls
from .min_flow_rate import min_flow_rate as min_flow_rate_cls
from .tan_source_term import tan_source_term as tan_source_term_cls
from .rad_source_term import rad_source_term as rad_source_term_cls
from .axial_source_term import axial_source_term as axial_source_term_cls
from .fan_axial_source_method import fan_axial_source_method as fan_axial_source_method_cls
from .fan_pre_jump import fan_pre_jump as fan_pre_jump_cls
from .fan_curve_fit import fan_curve_fit as fan_curve_fit_cls
from .fan_poly_order import fan_poly_order as fan_poly_order_cls
from .fan_ini_flow import fan_ini_flow as fan_ini_flow_cls
from .fan_test_angvel import fan_test_angvel as fan_test_angvel_cls
from .fan_test_temp import fan_test_temp as fan_test_temp_cls
from .fan_curve_filename import fan_curve_filename as fan_curve_filename_cls
from .reaction_mechs_1 import reaction_mechs as reaction_mechs_cls
from .react import react as react_cls
from .surface_volume_ratio import surface_volume_ratio as surface_volume_ratio_cls
from .electrolyte import electrolyte as electrolyte_cls
from .mp_compressive_beta_max import mp_compressive_beta_max as mp_compressive_beta_max_cls
from .mp_boiling_zone import mp_boiling_zone as mp_boiling_zone_cls
from .numerical_beach import numerical_beach as numerical_beach_cls
from .beach_id import beach_id as beach_id_cls
from .beach_multi_dir import beach_multi_dir as beach_multi_dir_cls
from .beach_damp_type import beach_damp_type as beach_damp_type_cls
from .beach_inlet_bndr import beach_inlet_bndr as beach_inlet_bndr_cls
from .beach_fs_level import beach_fs_level as beach_fs_level_cls
from .beach_bottom_level import beach_bottom_level as beach_bottom_level_cls
from .beach_dir_ni import beach_dir_ni as beach_dir_ni_cls
from .beach_dir_nj import beach_dir_nj as beach_dir_nj_cls
from .beach_dir_nk import beach_dir_nk as beach_dir_nk_cls
from .beach_damp_len_spec import beach_damp_len_spec as beach_damp_len_spec_cls
from .beach_wave_len import beach_wave_len as beach_wave_len_cls
from .beach_len_factor import beach_len_factor as beach_len_factor_cls
from .beach_start_point import beach_start_point as beach_start_point_cls
from .beach_end_point import beach_end_point as beach_end_point_cls
from .beach_dir_list import beach_dir_list as beach_dir_list_cls
from .beach_damp_relative import beach_damp_relative as beach_damp_relative_cls
from .beach_damp_resist_lin import beach_damp_resist_lin as beach_damp_resist_lin_cls
from .beach_damp_resist import beach_damp_resist as beach_damp_resist_cls
from .porous_structure import porous_structure as porous_structure_cls
from .structure_material import structure_material as structure_material_cls
from .anisotropic_spe_diff import anisotropic_spe_diff as anisotropic_spe_diff_cls
from .spe_diff_xx import spe_diff_xx as spe_diff_xx_cls
from .spe_diff_xy import spe_diff_xy as spe_diff_xy_cls
from .spe_diff_xz import spe_diff_xz as spe_diff_xz_cls
from .spe_diff_yx import spe_diff_yx as spe_diff_yx_cls
from .spe_diff_yy import spe_diff_yy as spe_diff_yy_cls
from .spe_diff_yz import spe_diff_yz as spe_diff_yz_cls
from .spe_diff_zx import spe_diff_zx as spe_diff_zx_cls
from .spe_diff_zy import spe_diff_zy as spe_diff_zy_cls
from .spe_diff_zz import spe_diff_zz as spe_diff_zz_cls
class fluid_child(Group):
    """
    'child_object_type' of fluid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'name', 'material', 'sources', 'source_terms', 'fixed',
         'cylindrical_fixed_var', 'fixes', 'motion_spec',
         'relative_to_thread', 'omega', 'axis_origin', 'axis_direction',
         'udf_zmotion_name', 'mrf_motion', 'mrf_relative_to_thread',
         'mrf_omega', 'reference_frame_velocity',
         'reference_frame_axis_origin', 'reference_frame_axis_direction',
         'mrf_udf_zmotion_name', 'mgrid_enable_transient', 'mgrid_motion',
         'mgrid_relative_to_thread', 'mgrid_omega', 'moving_mesh_velocity',
         'moving_mesh_axis_origin', 'moving_mesh_axis_direction',
         'mgrid_udf_zmotion_name', 'solid_motion', 'solid_relative_to_thread',
         'solid_omega', 'solid_motion_velocity', 'solid_motion_axis_origin',
         'solid_motion_axis_direction', 'solid_udf_zmotion_name', 'radiating',
         'les_embedded', 'contact_property', 'active_wetsteam_zone',
         'vapor_phase_realgas', 'laminar', 'laminar_mut_zero',
         'les_embedded_spec', 'les_embedded_mom_scheme',
         'les_embedded_c_wale', 'les_embedded_c_smag', 'glass', 'porous',
         'conical', 'dir_spec_cond', 'cursys', 'cursys_name', 'direction_1_x',
         'direction_1_y', 'direction_1_z', 'direction_2_x', 'direction_2_y',
         'direction_2_z', 'cone_axis_x', 'cone_axis_y', 'cone_axis_z',
         'cone_axis_pt_x', 'cone_axis_pt_y', 'cone_axis_pt_z', 'cone_angle',
         'rel_vel_resistance', 'porous_r_1', 'porous_r_2', 'porous_r_3',
         'alt_inertial_form', 'porous_c_1', 'porous_c_2', 'porous_c_3', 'c0',
         'c1', 'porosity', 'viscosity_ratio', 'none', 'corey', 'stone_1',
         'stone_2', 'rel_perm_limit_p1', 'rel_perm_limit_p2', 'ref_perm_p1',
         'exp_p1', 'res_sat_p1', 'ref_perm_p2', 'exp_p2', 'res_sat_p2',
         'ref_perm_p3', 'exp_p3', 'res_sat_p3', 'capillary_pressure',
         'max_capillary_pressure', 'van_genuchten_pg', 'van_genuchten_ng',
         'skjaeveland_nw_pc_coef', 'skjaeveland_nw_pc_pwr',
         'skjaeveland_wet_pc_coef', 'skjaeveland_wet_pc_pwr',
         'brooks_corey_pe', 'brooks_corey_ng', 'leverett_con_ang',
         'rel_perm_tabular_p1', 'rel_perm_table_p1', 'rel_perm_satw_p1',
         'rel_perm_rp_p1', 'rel_perm_tabular_p2', 'rel_perm_table_p2',
         'rel_perm_satw_p2', 'rel_perm_rp_p2', 'wetting_phase',
         'non_wetting_phase', 'equib_thermal', 'non_equib_thermal',
         'solid_material', 'area_density', 'heat_transfer_coeff', 'fanzone',
         'fan_zone_list', 'fan_thickness', 'fan_hub_rad', 'fan_tip_rad',
         'fan_x_origin', 'fan_y_origin', 'fan_z_origin', 'fan_rot_dir',
         'fan_opert_angvel', 'fan_inflection_point', 'limit_flow_fan',
         'max_flow_rate', 'min_flow_rate', 'tan_source_term',
         'rad_source_term', 'axial_source_term', 'fan_axial_source_method',
         'fan_pre_jump', 'fan_curve_fit', 'fan_poly_order', 'fan_ini_flow',
         'fan_test_angvel', 'fan_test_temp', 'fan_curve_filename',
         'reaction_mechs', 'react', 'surface_volume_ratio', 'electrolyte',
         'mp_compressive_beta_max', 'mp_boiling_zone', 'numerical_beach',
         'beach_id', 'beach_multi_dir', 'beach_damp_type', 'beach_inlet_bndr',
         'beach_fs_level', 'beach_bottom_level', 'beach_dir_ni',
         'beach_dir_nj', 'beach_dir_nk', 'beach_damp_len_spec',
         'beach_wave_len', 'beach_len_factor', 'beach_start_point',
         'beach_end_point', 'beach_dir_list', 'beach_damp_relative',
         'beach_damp_resist_lin', 'beach_damp_resist', 'porous_structure',
         'structure_material', 'anisotropic_spe_diff', 'spe_diff_xx',
         'spe_diff_xy', 'spe_diff_xz', 'spe_diff_yx', 'spe_diff_yy',
         'spe_diff_yz', 'spe_diff_zx', 'spe_diff_zy', 'spe_diff_zz']

    phase: phase_cls = phase_cls
    """
    phase child of fluid_child.
    """
    name: name_cls = name_cls
    """
    name child of fluid_child.
    """
    material: material_cls = material_cls
    """
    material child of fluid_child.
    """
    sources: sources_cls = sources_cls
    """
    sources child of fluid_child.
    """
    source_terms: source_terms_cls = source_terms_cls
    """
    source_terms child of fluid_child.
    """
    fixed: fixed_cls = fixed_cls
    """
    fixed child of fluid_child.
    """
    cylindrical_fixed_var: cylindrical_fixed_var_cls = cylindrical_fixed_var_cls
    """
    cylindrical_fixed_var child of fluid_child.
    """
    fixes: fixes_cls = fixes_cls
    """
    fixes child of fluid_child.
    """
    motion_spec: motion_spec_cls = motion_spec_cls
    """
    motion_spec child of fluid_child.
    """
    relative_to_thread: relative_to_thread_cls = relative_to_thread_cls
    """
    relative_to_thread child of fluid_child.
    """
    omega: omega_cls = omega_cls
    """
    omega child of fluid_child.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of fluid_child.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of fluid_child.
    """
    udf_zmotion_name: udf_zmotion_name_cls = udf_zmotion_name_cls
    """
    udf_zmotion_name child of fluid_child.
    """
    mrf_motion: mrf_motion_cls = mrf_motion_cls
    """
    mrf_motion child of fluid_child.
    """
    mrf_relative_to_thread: mrf_relative_to_thread_cls = mrf_relative_to_thread_cls
    """
    mrf_relative_to_thread child of fluid_child.
    """
    mrf_omega: mrf_omega_cls = mrf_omega_cls
    """
    mrf_omega child of fluid_child.
    """
    reference_frame_velocity: reference_frame_velocity_cls = reference_frame_velocity_cls
    """
    reference_frame_velocity child of fluid_child.
    """
    reference_frame_axis_origin: reference_frame_axis_origin_cls = reference_frame_axis_origin_cls
    """
    reference_frame_axis_origin child of fluid_child.
    """
    reference_frame_axis_direction: reference_frame_axis_direction_cls = reference_frame_axis_direction_cls
    """
    reference_frame_axis_direction child of fluid_child.
    """
    mrf_udf_zmotion_name: mrf_udf_zmotion_name_cls = mrf_udf_zmotion_name_cls
    """
    mrf_udf_zmotion_name child of fluid_child.
    """
    mgrid_enable_transient: mgrid_enable_transient_cls = mgrid_enable_transient_cls
    """
    mgrid_enable_transient child of fluid_child.
    """
    mgrid_motion: mgrid_motion_cls = mgrid_motion_cls
    """
    mgrid_motion child of fluid_child.
    """
    mgrid_relative_to_thread: mgrid_relative_to_thread_cls = mgrid_relative_to_thread_cls
    """
    mgrid_relative_to_thread child of fluid_child.
    """
    mgrid_omega: mgrid_omega_cls = mgrid_omega_cls
    """
    mgrid_omega child of fluid_child.
    """
    moving_mesh_velocity: moving_mesh_velocity_cls = moving_mesh_velocity_cls
    """
    moving_mesh_velocity child of fluid_child.
    """
    moving_mesh_axis_origin: moving_mesh_axis_origin_cls = moving_mesh_axis_origin_cls
    """
    moving_mesh_axis_origin child of fluid_child.
    """
    moving_mesh_axis_direction: moving_mesh_axis_direction_cls = moving_mesh_axis_direction_cls
    """
    moving_mesh_axis_direction child of fluid_child.
    """
    mgrid_udf_zmotion_name: mgrid_udf_zmotion_name_cls = mgrid_udf_zmotion_name_cls
    """
    mgrid_udf_zmotion_name child of fluid_child.
    """
    solid_motion: solid_motion_cls = solid_motion_cls
    """
    solid_motion child of fluid_child.
    """
    solid_relative_to_thread: solid_relative_to_thread_cls = solid_relative_to_thread_cls
    """
    solid_relative_to_thread child of fluid_child.
    """
    solid_omega: solid_omega_cls = solid_omega_cls
    """
    solid_omega child of fluid_child.
    """
    solid_motion_velocity: solid_motion_velocity_cls = solid_motion_velocity_cls
    """
    solid_motion_velocity child of fluid_child.
    """
    solid_motion_axis_origin: solid_motion_axis_origin_cls = solid_motion_axis_origin_cls
    """
    solid_motion_axis_origin child of fluid_child.
    """
    solid_motion_axis_direction: solid_motion_axis_direction_cls = solid_motion_axis_direction_cls
    """
    solid_motion_axis_direction child of fluid_child.
    """
    solid_udf_zmotion_name: solid_udf_zmotion_name_cls = solid_udf_zmotion_name_cls
    """
    solid_udf_zmotion_name child of fluid_child.
    """
    radiating: radiating_cls = radiating_cls
    """
    radiating child of fluid_child.
    """
    les_embedded: les_embedded_cls = les_embedded_cls
    """
    les_embedded child of fluid_child.
    """
    contact_property: contact_property_cls = contact_property_cls
    """
    contact_property child of fluid_child.
    """
    active_wetsteam_zone: active_wetsteam_zone_cls = active_wetsteam_zone_cls
    """
    active_wetsteam_zone child of fluid_child.
    """
    vapor_phase_realgas: vapor_phase_realgas_cls = vapor_phase_realgas_cls
    """
    vapor_phase_realgas child of fluid_child.
    """
    laminar: laminar_cls = laminar_cls
    """
    laminar child of fluid_child.
    """
    laminar_mut_zero: laminar_mut_zero_cls = laminar_mut_zero_cls
    """
    laminar_mut_zero child of fluid_child.
    """
    les_embedded_spec: les_embedded_spec_cls = les_embedded_spec_cls
    """
    les_embedded_spec child of fluid_child.
    """
    les_embedded_mom_scheme: les_embedded_mom_scheme_cls = les_embedded_mom_scheme_cls
    """
    les_embedded_mom_scheme child of fluid_child.
    """
    les_embedded_c_wale: les_embedded_c_wale_cls = les_embedded_c_wale_cls
    """
    les_embedded_c_wale child of fluid_child.
    """
    les_embedded_c_smag: les_embedded_c_smag_cls = les_embedded_c_smag_cls
    """
    les_embedded_c_smag child of fluid_child.
    """
    glass: glass_cls = glass_cls
    """
    glass child of fluid_child.
    """
    porous: porous_cls = porous_cls
    """
    porous child of fluid_child.
    """
    conical: conical_cls = conical_cls
    """
    conical child of fluid_child.
    """
    dir_spec_cond: dir_spec_cond_cls = dir_spec_cond_cls
    """
    dir_spec_cond child of fluid_child.
    """
    cursys: cursys_cls = cursys_cls
    """
    cursys child of fluid_child.
    """
    cursys_name: cursys_name_cls = cursys_name_cls
    """
    cursys_name child of fluid_child.
    """
    direction_1_x: direction_1_x_cls = direction_1_x_cls
    """
    direction_1_x child of fluid_child.
    """
    direction_1_y: direction_1_y_cls = direction_1_y_cls
    """
    direction_1_y child of fluid_child.
    """
    direction_1_z: direction_1_z_cls = direction_1_z_cls
    """
    direction_1_z child of fluid_child.
    """
    direction_2_x: direction_2_x_cls = direction_2_x_cls
    """
    direction_2_x child of fluid_child.
    """
    direction_2_y: direction_2_y_cls = direction_2_y_cls
    """
    direction_2_y child of fluid_child.
    """
    direction_2_z: direction_2_z_cls = direction_2_z_cls
    """
    direction_2_z child of fluid_child.
    """
    cone_axis_x: cone_axis_x_cls = cone_axis_x_cls
    """
    cone_axis_x child of fluid_child.
    """
    cone_axis_y: cone_axis_y_cls = cone_axis_y_cls
    """
    cone_axis_y child of fluid_child.
    """
    cone_axis_z: cone_axis_z_cls = cone_axis_z_cls
    """
    cone_axis_z child of fluid_child.
    """
    cone_axis_pt_x: cone_axis_pt_x_cls = cone_axis_pt_x_cls
    """
    cone_axis_pt_x child of fluid_child.
    """
    cone_axis_pt_y: cone_axis_pt_y_cls = cone_axis_pt_y_cls
    """
    cone_axis_pt_y child of fluid_child.
    """
    cone_axis_pt_z: cone_axis_pt_z_cls = cone_axis_pt_z_cls
    """
    cone_axis_pt_z child of fluid_child.
    """
    cone_angle: cone_angle_cls = cone_angle_cls
    """
    cone_angle child of fluid_child.
    """
    rel_vel_resistance: rel_vel_resistance_cls = rel_vel_resistance_cls
    """
    rel_vel_resistance child of fluid_child.
    """
    porous_r_1: porous_r_1_cls = porous_r_1_cls
    """
    porous_r_1 child of fluid_child.
    """
    porous_r_2: porous_r_2_cls = porous_r_2_cls
    """
    porous_r_2 child of fluid_child.
    """
    porous_r_3: porous_r_3_cls = porous_r_3_cls
    """
    porous_r_3 child of fluid_child.
    """
    alt_inertial_form: alt_inertial_form_cls = alt_inertial_form_cls
    """
    alt_inertial_form child of fluid_child.
    """
    porous_c_1: porous_c_1_cls = porous_c_1_cls
    """
    porous_c_1 child of fluid_child.
    """
    porous_c_2: porous_c_2_cls = porous_c_2_cls
    """
    porous_c_2 child of fluid_child.
    """
    porous_c_3: porous_c_3_cls = porous_c_3_cls
    """
    porous_c_3 child of fluid_child.
    """
    c0: c0_cls = c0_cls
    """
    c0 child of fluid_child.
    """
    c1: c1_cls = c1_cls
    """
    c1 child of fluid_child.
    """
    porosity: porosity_cls = porosity_cls
    """
    porosity child of fluid_child.
    """
    viscosity_ratio: viscosity_ratio_cls = viscosity_ratio_cls
    """
    viscosity_ratio child of fluid_child.
    """
    none: none_cls = none_cls
    """
    none child of fluid_child.
    """
    corey: corey_cls = corey_cls
    """
    corey child of fluid_child.
    """
    stone_1: stone_1_cls = stone_1_cls
    """
    stone_1 child of fluid_child.
    """
    stone_2: stone_2_cls = stone_2_cls
    """
    stone_2 child of fluid_child.
    """
    rel_perm_limit_p1: rel_perm_limit_p1_cls = rel_perm_limit_p1_cls
    """
    rel_perm_limit_p1 child of fluid_child.
    """
    rel_perm_limit_p2: rel_perm_limit_p2_cls = rel_perm_limit_p2_cls
    """
    rel_perm_limit_p2 child of fluid_child.
    """
    ref_perm_p1: ref_perm_p1_cls = ref_perm_p1_cls
    """
    ref_perm_p1 child of fluid_child.
    """
    exp_p1: exp_p1_cls = exp_p1_cls
    """
    exp_p1 child of fluid_child.
    """
    res_sat_p1: res_sat_p1_cls = res_sat_p1_cls
    """
    res_sat_p1 child of fluid_child.
    """
    ref_perm_p2: ref_perm_p2_cls = ref_perm_p2_cls
    """
    ref_perm_p2 child of fluid_child.
    """
    exp_p2: exp_p2_cls = exp_p2_cls
    """
    exp_p2 child of fluid_child.
    """
    res_sat_p2: res_sat_p2_cls = res_sat_p2_cls
    """
    res_sat_p2 child of fluid_child.
    """
    ref_perm_p3: ref_perm_p3_cls = ref_perm_p3_cls
    """
    ref_perm_p3 child of fluid_child.
    """
    exp_p3: exp_p3_cls = exp_p3_cls
    """
    exp_p3 child of fluid_child.
    """
    res_sat_p3: res_sat_p3_cls = res_sat_p3_cls
    """
    res_sat_p3 child of fluid_child.
    """
    capillary_pressure: capillary_pressure_cls = capillary_pressure_cls
    """
    capillary_pressure child of fluid_child.
    """
    max_capillary_pressure: max_capillary_pressure_cls = max_capillary_pressure_cls
    """
    max_capillary_pressure child of fluid_child.
    """
    van_genuchten_pg: van_genuchten_pg_cls = van_genuchten_pg_cls
    """
    van_genuchten_pg child of fluid_child.
    """
    van_genuchten_ng: van_genuchten_ng_cls = van_genuchten_ng_cls
    """
    van_genuchten_ng child of fluid_child.
    """
    skjaeveland_nw_pc_coef: skjaeveland_nw_pc_coef_cls = skjaeveland_nw_pc_coef_cls
    """
    skjaeveland_nw_pc_coef child of fluid_child.
    """
    skjaeveland_nw_pc_pwr: skjaeveland_nw_pc_pwr_cls = skjaeveland_nw_pc_pwr_cls
    """
    skjaeveland_nw_pc_pwr child of fluid_child.
    """
    skjaeveland_wet_pc_coef: skjaeveland_wet_pc_coef_cls = skjaeveland_wet_pc_coef_cls
    """
    skjaeveland_wet_pc_coef child of fluid_child.
    """
    skjaeveland_wet_pc_pwr: skjaeveland_wet_pc_pwr_cls = skjaeveland_wet_pc_pwr_cls
    """
    skjaeveland_wet_pc_pwr child of fluid_child.
    """
    brooks_corey_pe: brooks_corey_pe_cls = brooks_corey_pe_cls
    """
    brooks_corey_pe child of fluid_child.
    """
    brooks_corey_ng: brooks_corey_ng_cls = brooks_corey_ng_cls
    """
    brooks_corey_ng child of fluid_child.
    """
    leverett_con_ang: leverett_con_ang_cls = leverett_con_ang_cls
    """
    leverett_con_ang child of fluid_child.
    """
    rel_perm_tabular_p1: rel_perm_tabular_p1_cls = rel_perm_tabular_p1_cls
    """
    rel_perm_tabular_p1 child of fluid_child.
    """
    rel_perm_table_p1: rel_perm_table_p1_cls = rel_perm_table_p1_cls
    """
    rel_perm_table_p1 child of fluid_child.
    """
    rel_perm_satw_p1: rel_perm_satw_p1_cls = rel_perm_satw_p1_cls
    """
    rel_perm_satw_p1 child of fluid_child.
    """
    rel_perm_rp_p1: rel_perm_rp_p1_cls = rel_perm_rp_p1_cls
    """
    rel_perm_rp_p1 child of fluid_child.
    """
    rel_perm_tabular_p2: rel_perm_tabular_p2_cls = rel_perm_tabular_p2_cls
    """
    rel_perm_tabular_p2 child of fluid_child.
    """
    rel_perm_table_p2: rel_perm_table_p2_cls = rel_perm_table_p2_cls
    """
    rel_perm_table_p2 child of fluid_child.
    """
    rel_perm_satw_p2: rel_perm_satw_p2_cls = rel_perm_satw_p2_cls
    """
    rel_perm_satw_p2 child of fluid_child.
    """
    rel_perm_rp_p2: rel_perm_rp_p2_cls = rel_perm_rp_p2_cls
    """
    rel_perm_rp_p2 child of fluid_child.
    """
    wetting_phase: wetting_phase_cls = wetting_phase_cls
    """
    wetting_phase child of fluid_child.
    """
    non_wetting_phase: non_wetting_phase_cls = non_wetting_phase_cls
    """
    non_wetting_phase child of fluid_child.
    """
    equib_thermal: equib_thermal_cls = equib_thermal_cls
    """
    equib_thermal child of fluid_child.
    """
    non_equib_thermal: non_equib_thermal_cls = non_equib_thermal_cls
    """
    non_equib_thermal child of fluid_child.
    """
    solid_material: solid_material_cls = solid_material_cls
    """
    solid_material child of fluid_child.
    """
    area_density: area_density_cls = area_density_cls
    """
    area_density child of fluid_child.
    """
    heat_transfer_coeff: heat_transfer_coeff_cls = heat_transfer_coeff_cls
    """
    heat_transfer_coeff child of fluid_child.
    """
    fanzone: fanzone_cls = fanzone_cls
    """
    fanzone child of fluid_child.
    """
    fan_zone_list: fan_zone_list_cls = fan_zone_list_cls
    """
    fan_zone_list child of fluid_child.
    """
    fan_thickness: fan_thickness_cls = fan_thickness_cls
    """
    fan_thickness child of fluid_child.
    """
    fan_hub_rad: fan_hub_rad_cls = fan_hub_rad_cls
    """
    fan_hub_rad child of fluid_child.
    """
    fan_tip_rad: fan_tip_rad_cls = fan_tip_rad_cls
    """
    fan_tip_rad child of fluid_child.
    """
    fan_x_origin: fan_x_origin_cls = fan_x_origin_cls
    """
    fan_x_origin child of fluid_child.
    """
    fan_y_origin: fan_y_origin_cls = fan_y_origin_cls
    """
    fan_y_origin child of fluid_child.
    """
    fan_z_origin: fan_z_origin_cls = fan_z_origin_cls
    """
    fan_z_origin child of fluid_child.
    """
    fan_rot_dir: fan_rot_dir_cls = fan_rot_dir_cls
    """
    fan_rot_dir child of fluid_child.
    """
    fan_opert_angvel: fan_opert_angvel_cls = fan_opert_angvel_cls
    """
    fan_opert_angvel child of fluid_child.
    """
    fan_inflection_point: fan_inflection_point_cls = fan_inflection_point_cls
    """
    fan_inflection_point child of fluid_child.
    """
    limit_flow_fan: limit_flow_fan_cls = limit_flow_fan_cls
    """
    limit_flow_fan child of fluid_child.
    """
    max_flow_rate: max_flow_rate_cls = max_flow_rate_cls
    """
    max_flow_rate child of fluid_child.
    """
    min_flow_rate: min_flow_rate_cls = min_flow_rate_cls
    """
    min_flow_rate child of fluid_child.
    """
    tan_source_term: tan_source_term_cls = tan_source_term_cls
    """
    tan_source_term child of fluid_child.
    """
    rad_source_term: rad_source_term_cls = rad_source_term_cls
    """
    rad_source_term child of fluid_child.
    """
    axial_source_term: axial_source_term_cls = axial_source_term_cls
    """
    axial_source_term child of fluid_child.
    """
    fan_axial_source_method: fan_axial_source_method_cls = fan_axial_source_method_cls
    """
    fan_axial_source_method child of fluid_child.
    """
    fan_pre_jump: fan_pre_jump_cls = fan_pre_jump_cls
    """
    fan_pre_jump child of fluid_child.
    """
    fan_curve_fit: fan_curve_fit_cls = fan_curve_fit_cls
    """
    fan_curve_fit child of fluid_child.
    """
    fan_poly_order: fan_poly_order_cls = fan_poly_order_cls
    """
    fan_poly_order child of fluid_child.
    """
    fan_ini_flow: fan_ini_flow_cls = fan_ini_flow_cls
    """
    fan_ini_flow child of fluid_child.
    """
    fan_test_angvel: fan_test_angvel_cls = fan_test_angvel_cls
    """
    fan_test_angvel child of fluid_child.
    """
    fan_test_temp: fan_test_temp_cls = fan_test_temp_cls
    """
    fan_test_temp child of fluid_child.
    """
    fan_curve_filename: fan_curve_filename_cls = fan_curve_filename_cls
    """
    fan_curve_filename child of fluid_child.
    """
    reaction_mechs: reaction_mechs_cls = reaction_mechs_cls
    """
    reaction_mechs child of fluid_child.
    """
    react: react_cls = react_cls
    """
    react child of fluid_child.
    """
    surface_volume_ratio: surface_volume_ratio_cls = surface_volume_ratio_cls
    """
    surface_volume_ratio child of fluid_child.
    """
    electrolyte: electrolyte_cls = electrolyte_cls
    """
    electrolyte child of fluid_child.
    """
    mp_compressive_beta_max: mp_compressive_beta_max_cls = mp_compressive_beta_max_cls
    """
    mp_compressive_beta_max child of fluid_child.
    """
    mp_boiling_zone: mp_boiling_zone_cls = mp_boiling_zone_cls
    """
    mp_boiling_zone child of fluid_child.
    """
    numerical_beach: numerical_beach_cls = numerical_beach_cls
    """
    numerical_beach child of fluid_child.
    """
    beach_id: beach_id_cls = beach_id_cls
    """
    beach_id child of fluid_child.
    """
    beach_multi_dir: beach_multi_dir_cls = beach_multi_dir_cls
    """
    beach_multi_dir child of fluid_child.
    """
    beach_damp_type: beach_damp_type_cls = beach_damp_type_cls
    """
    beach_damp_type child of fluid_child.
    """
    beach_inlet_bndr: beach_inlet_bndr_cls = beach_inlet_bndr_cls
    """
    beach_inlet_bndr child of fluid_child.
    """
    beach_fs_level: beach_fs_level_cls = beach_fs_level_cls
    """
    beach_fs_level child of fluid_child.
    """
    beach_bottom_level: beach_bottom_level_cls = beach_bottom_level_cls
    """
    beach_bottom_level child of fluid_child.
    """
    beach_dir_ni: beach_dir_ni_cls = beach_dir_ni_cls
    """
    beach_dir_ni child of fluid_child.
    """
    beach_dir_nj: beach_dir_nj_cls = beach_dir_nj_cls
    """
    beach_dir_nj child of fluid_child.
    """
    beach_dir_nk: beach_dir_nk_cls = beach_dir_nk_cls
    """
    beach_dir_nk child of fluid_child.
    """
    beach_damp_len_spec: beach_damp_len_spec_cls = beach_damp_len_spec_cls
    """
    beach_damp_len_spec child of fluid_child.
    """
    beach_wave_len: beach_wave_len_cls = beach_wave_len_cls
    """
    beach_wave_len child of fluid_child.
    """
    beach_len_factor: beach_len_factor_cls = beach_len_factor_cls
    """
    beach_len_factor child of fluid_child.
    """
    beach_start_point: beach_start_point_cls = beach_start_point_cls
    """
    beach_start_point child of fluid_child.
    """
    beach_end_point: beach_end_point_cls = beach_end_point_cls
    """
    beach_end_point child of fluid_child.
    """
    beach_dir_list: beach_dir_list_cls = beach_dir_list_cls
    """
    beach_dir_list child of fluid_child.
    """
    beach_damp_relative: beach_damp_relative_cls = beach_damp_relative_cls
    """
    beach_damp_relative child of fluid_child.
    """
    beach_damp_resist_lin: beach_damp_resist_lin_cls = beach_damp_resist_lin_cls
    """
    beach_damp_resist_lin child of fluid_child.
    """
    beach_damp_resist: beach_damp_resist_cls = beach_damp_resist_cls
    """
    beach_damp_resist child of fluid_child.
    """
    porous_structure: porous_structure_cls = porous_structure_cls
    """
    porous_structure child of fluid_child.
    """
    structure_material: structure_material_cls = structure_material_cls
    """
    structure_material child of fluid_child.
    """
    anisotropic_spe_diff: anisotropic_spe_diff_cls = anisotropic_spe_diff_cls
    """
    anisotropic_spe_diff child of fluid_child.
    """
    spe_diff_xx: spe_diff_xx_cls = spe_diff_xx_cls
    """
    spe_diff_xx child of fluid_child.
    """
    spe_diff_xy: spe_diff_xy_cls = spe_diff_xy_cls
    """
    spe_diff_xy child of fluid_child.
    """
    spe_diff_xz: spe_diff_xz_cls = spe_diff_xz_cls
    """
    spe_diff_xz child of fluid_child.
    """
    spe_diff_yx: spe_diff_yx_cls = spe_diff_yx_cls
    """
    spe_diff_yx child of fluid_child.
    """
    spe_diff_yy: spe_diff_yy_cls = spe_diff_yy_cls
    """
    spe_diff_yy child of fluid_child.
    """
    spe_diff_yz: spe_diff_yz_cls = spe_diff_yz_cls
    """
    spe_diff_yz child of fluid_child.
    """
    spe_diff_zx: spe_diff_zx_cls = spe_diff_zx_cls
    """
    spe_diff_zx child of fluid_child.
    """
    spe_diff_zy: spe_diff_zy_cls = spe_diff_zy_cls
    """
    spe_diff_zy child of fluid_child.
    """
    spe_diff_zz: spe_diff_zz_cls = spe_diff_zz_cls
    """
    spe_diff_zz child of fluid_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class gpgpu_statistics(Command):
    """
    GPGPU information.
    """

    fluent_name = "gpgpu-statistics"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class disk_origin_x(Real):
    """
    Set rotor origin x-coordinate.
    """

    fluent_name = "disk-origin-x"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .n_smooth_for_interfacial_regims import n_smooth_for_interfacial_regims as n_smooth_for_interfacial_regims_cls
from .sm_relax_factor import sm_relax_factor as sm_relax_factor_cls
from .viscous_func_options import viscous_func_options as viscous_func_options_cls
from .density_func_options import density_func_options as density_func_options_cls
from .exponent_smoothing_func import exponent_smoothing_func as exponent_smoothing_func_cls
from .exponent_density_func import exponent_density_func as exponent_density_func_cls
from .boundry_treatment import boundry_treatment as boundry_treatment_cls
from .near_wall_treatment_1 import near_wall_treatment as near_wall_treatment_cls
class interfacial_artificial_viscosity(Group):
    """
    'interfacial_artificial_viscosity' child.
    """

    fluent_name = "interfacial-artificial-viscosity"

    child_names = \
        ['n_smooth_for_interfacial_regims', 'sm_relax_factor',
         'viscous_func_options', 'density_func_options',
         'exponent_smoothing_func', 'exponent_density_func',
         'boundry_treatment', 'near_wall_treatment']

    n_smooth_for_interfacial_regims: n_smooth_for_interfacial_regims_cls = n_smooth_for_interfacial_regims_cls
    """
    n_smooth_for_interfacial_regims child of interfacial_artificial_viscosity.
    """
    sm_relax_factor: sm_relax_factor_cls = sm_relax_factor_cls
    """
    sm_relax_factor child of interfacial_artificial_viscosity.
    """
    viscous_func_options: viscous_func_options_cls = viscous_func_options_cls
    """
    viscous_func_options child of interfacial_artificial_viscosity.
    """
    density_func_options: density_func_options_cls = density_func_options_cls
    """
    density_func_options child of interfacial_artificial_viscosity.
    """
    exponent_smoothing_func: exponent_smoothing_func_cls = exponent_smoothing_func_cls
    """
    exponent_smoothing_func child of interfacial_artificial_viscosity.
    """
    exponent_density_func: exponent_density_func_cls = exponent_density_func_cls
    """
    exponent_density_func child of interfacial_artificial_viscosity.
    """
    boundry_treatment: boundry_treatment_cls = boundry_treatment_cls
    """
    boundry_treatment child of interfacial_artificial_viscosity.
    """
    near_wall_treatment: near_wall_treatment_cls = near_wall_treatment_cls
    """
    near_wall_treatment child of interfacial_artificial_viscosity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .draw_major_rules import draw_major_rules as draw_major_rules_cls
from .major_rule_weight import major_rule_weight as major_rule_weight_cls
from .major_rule_line_color import major_rule_line_color as major_rule_line_color_cls
from .draw_minor_rules import draw_minor_rules as draw_minor_rules_cls
from .minor_rule_weight import minor_rule_weight as minor_rule_weight_cls
from .minor_rule_line_color import minor_rule_line_color as minor_rule_line_color_cls
class y_axis(Group):
    """
    'y_axis' child.
    """

    fluent_name = "y-axis"

    child_names = \
        ['draw_major_rules', 'major_rule_weight', 'major_rule_line_color',
         'draw_minor_rules', 'minor_rule_weight', 'minor_rule_line_color']

    draw_major_rules: draw_major_rules_cls = draw_major_rules_cls
    """
    draw_major_rules child of y_axis.
    """
    major_rule_weight: major_rule_weight_cls = major_rule_weight_cls
    """
    major_rule_weight child of y_axis.
    """
    major_rule_line_color: major_rule_line_color_cls = major_rule_line_color_cls
    """
    major_rule_line_color child of y_axis.
    """
    draw_minor_rules: draw_minor_rules_cls = draw_minor_rules_cls
    """
    draw_minor_rules child of y_axis.
    """
    minor_rule_weight: minor_rule_weight_cls = minor_rule_weight_cls
    """
    minor_rule_weight child of y_axis.
    """
    minor_rule_line_color: minor_rule_line_color_cls = minor_rule_line_color_cls
    """
    minor_rule_line_color child of y_axis.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class control_by(String, _HasAllowedValuesMixin):
    """
    Select the option to determine the initial tracking step length.
    """

    fluent_name = "control-by"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class scalars_skew_diffusion_exclude(Boolean):
    """
    Exclude skew diffusion discretization contribution for scalars.
    """

    fluent_name = "scalars-skew-diffusion-exclude?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .yplus_1 import yplus as yplus_cls
from .ystar import ystar as ystar_cls
class option(Group):
    """
    'option' child.
    """

    fluent_name = "option"

    child_names = \
        ['option', 'yplus', 'ystar']

    option: option_cls = option_cls
    """
    option child of option.
    """
    yplus: yplus_cls = yplus_cls
    """
    yplus child of option.
    """
    ystar: ystar_cls = ystar_cls
    """
    ystar child of option.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .volume_fraction_constant import volume_fraction_constant as volume_fraction_constant_cls
from .time_scale_constant import time_scale_constant as time_scale_constant_cls
class edc_constant_coefficient_options(Group):
    """
    'edc_constant_coefficient_options' child.
    """

    fluent_name = "edc-constant-coefficient-options"

    child_names = \
        ['volume_fraction_constant', 'time_scale_constant']

    volume_fraction_constant: volume_fraction_constant_cls = volume_fraction_constant_cls
    """
    volume_fraction_constant child of edc_constant_coefficient_options.
    """
    time_scale_constant: time_scale_constant_cls = time_scale_constant_cls
    """
    time_scale_constant child of edc_constant_coefficient_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class cell_zones(StringList):
    """
    Set cell zones to be used for marking adaption. An empty list implies that all zones are considered for adaption.
    """

    fluent_name = "cell-zones"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class non_conformal_interface_numerics:
    fluent_name = ...
    command_names = ...

    def change_numerics(self, use_sided_area_vector: bool, use_nci_sided_area_vectors: bool, recrete: bool):
        """
        Enable modified non-conformal interface numerics.
        
        Parameters
        ----------
            use_sided_area_vector : bool
                'use_sided_area_vector' child.
            use_nci_sided_area_vectors : bool
                'use_nci_sided_area_vectors' child.
            recrete : bool
                'recrete' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class enable_local_mapped_tolerance(Boolean):
    """
    Enable local tolerance for this mesh interface.
    """

    fluent_name = "enable-local-mapped-tolerance?"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class reduction:
    fluent_name = ...
    child_names = ...
    setup_reduction = ...
    command_names = ...

    def pick_sample_to_reduce(self, change_curr_sample: bool, sample: str):
        """
        Pick a sample for which to first set-up and then perform the data reduction.
        
        Parameters
        ----------
            change_curr_sample : bool
                'change_curr_sample' child.
            sample : str
                'sample' child.
        
        """

    def reduce_picked_sample(self, check_reduction_wt: bool, file_name: str, overwrite: bool):
        """
        Reduce a sample after first picking it and setting up all data-reduction options and parameters.
        
        Parameters
        ----------
            check_reduction_wt : bool
                'check_reduction_wt' child.
            file_name : str
                'file_name' child.
            overwrite : bool
                'overwrite' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .axes_2 import axes as axes_cls
from .main import main as main_cls
from .scale_3 import scale as scale_cls
from .text import text as text_cls
from .video import video as video_cls
from .xy import xy as xy_cls
from .logo import logo as logo_cls
from .ruler_1 import ruler as ruler_cls
from .logo_color import logo_color as logo_color_cls
from .aspect_ratio import aspect_ratio as aspect_ratio_cls
class windows(Group):
    """
    'windows' child.
    """

    fluent_name = "windows"

    child_names = \
        ['axes', 'main', 'scale', 'text', 'video', 'xy', 'logo', 'ruler',
         'logo_color']

    axes: axes_cls = axes_cls
    """
    axes child of windows.
    """
    main: main_cls = main_cls
    """
    main child of windows.
    """
    scale: scale_cls = scale_cls
    """
    scale child of windows.
    """
    text: text_cls = text_cls
    """
    text child of windows.
    """
    video: video_cls = video_cls
    """
    video child of windows.
    """
    xy: xy_cls = xy_cls
    """
    xy child of windows.
    """
    logo: logo_cls = logo_cls
    """
    logo child of windows.
    """
    ruler: ruler_cls = ruler_cls
    """
    ruler child of windows.
    """
    logo_color: logo_color_cls = logo_color_cls
    """
    logo_color child of windows.
    """
    command_names = \
        ['aspect_ratio']

    aspect_ratio: aspect_ratio_cls = aspect_ratio_cls
    """
    aspect_ratio command of windows.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_mesh_interface_clustering import enable_mesh_interface_clustering as enable_mesh_interface_clustering_cls
from .split_angle import split_angle as split_angle_cls
from .clustering_algorithm import clustering_algorithm as clustering_algorithm_cls
from .faces_per_cluster import faces_per_cluster as faces_per_cluster_cls
from .print_thread_clusters import print_thread_clusters as print_thread_clusters_cls
class clustering_settings(Group):
    """
    Enter clustering related settings.
    """

    fluent_name = "clustering-settings"

    child_names = \
        ['enable_mesh_interface_clustering', 'split_angle',
         'clustering_algorithm', 'faces_per_cluster']

    enable_mesh_interface_clustering: enable_mesh_interface_clustering_cls = enable_mesh_interface_clustering_cls
    """
    enable_mesh_interface_clustering child of clustering_settings.
    """
    split_angle: split_angle_cls = split_angle_cls
    """
    split_angle child of clustering_settings.
    """
    clustering_algorithm: clustering_algorithm_cls = clustering_algorithm_cls
    """
    clustering_algorithm child of clustering_settings.
    """
    faces_per_cluster: faces_per_cluster_cls = faces_per_cluster_cls
    """
    faces_per_cluster child of clustering_settings.
    """
    command_names = \
        ['print_thread_clusters']

    print_thread_clusters: print_thread_clusters_cls = print_thread_clusters_cls
    """
    print_thread_clusters command of clustering_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .location_1 import location as location_cls
from .matrix import matrix as matrix_cls
from .cone_settings import cone_settings as cone_settings_cls
from .velocity import velocity as velocity_cls
from .angular_velocity import angular_velocity as angular_velocity_cls
from .mass_flow_rate import mass_flow_rate as mass_flow_rate_cls
from .times import times as times_cls
from .particle_size import particle_size as particle_size_cls
from .temperature import temperature as temperature_cls
from .temperature_2 import temperature_2 as temperature_2_cls
class initial_props(Group):
    """
    'initial_props' child.
    """

    fluent_name = "initial-props"

    child_names = \
        ['location', 'matrix', 'cone_settings', 'velocity',
         'angular_velocity', 'mass_flow_rate', 'times', 'particle_size',
         'temperature', 'temperature_2']

    location: location_cls = location_cls
    """
    location child of initial_props.
    """
    matrix: matrix_cls = matrix_cls
    """
    matrix child of initial_props.
    """
    cone_settings: cone_settings_cls = cone_settings_cls
    """
    cone_settings child of initial_props.
    """
    velocity: velocity_cls = velocity_cls
    """
    velocity child of initial_props.
    """
    angular_velocity: angular_velocity_cls = angular_velocity_cls
    """
    angular_velocity child of initial_props.
    """
    mass_flow_rate: mass_flow_rate_cls = mass_flow_rate_cls
    """
    mass_flow_rate child of initial_props.
    """
    times: times_cls = times_cls
    """
    times child of initial_props.
    """
    particle_size: particle_size_cls = particle_size_cls
    """
    particle_size child of initial_props.
    """
    temperature: temperature_cls = temperature_cls
    """
    temperature child of initial_props.
    """
    temperature_2: temperature_2_cls = temperature_2_cls
    """
    temperature_2 child of initial_props.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .change_type import change_type as change_type_cls
from .wall_child import wall_child

class wall(NamedObject[wall_child], _CreatableNamedObjectMixin[wall_child]):
    """
    'wall' child.
    """

    fluent_name = "wall"

    command_names = \
        ['change_type']

    change_type: change_type_cls = change_type_cls
    """
    change_type command of wall.
    """
    child_object_type: wall_child = wall_child
    """
    child_object_type of wall.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .particle_type import particle_type as particle_type_cls
from .material import material as material_cls
from .reference_frame import reference_frame as reference_frame_cls
from .number_of_streams import number_of_streams as number_of_streams_cls
from .injection_type import injection_type as injection_type_cls
from .interaction_1 import interaction as interaction_cls
from .parcel_method import parcel_method as parcel_method_cls
from .particle_reinjector import particle_reinjector as particle_reinjector_cls
from .physical_models import physical_models as physical_models_cls
from .initial_props import initial_props as initial_props_cls
class injections_child(Group):
    """
    'child_object_type' of injections.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['particle_type', 'material', 'reference_frame', 'number_of_streams',
         'injection_type', 'interaction', 'parcel_method',
         'particle_reinjector', 'physical_models', 'initial_props']

    particle_type: particle_type_cls = particle_type_cls
    """
    particle_type child of injections_child.
    """
    material: material_cls = material_cls
    """
    material child of injections_child.
    """
    reference_frame: reference_frame_cls = reference_frame_cls
    """
    reference_frame child of injections_child.
    """
    number_of_streams: number_of_streams_cls = number_of_streams_cls
    """
    number_of_streams child of injections_child.
    """
    injection_type: injection_type_cls = injection_type_cls
    """
    injection_type child of injections_child.
    """
    interaction: interaction_cls = interaction_cls
    """
    interaction child of injections_child.
    """
    parcel_method: parcel_method_cls = parcel_method_cls
    """
    parcel_method child of injections_child.
    """
    particle_reinjector: particle_reinjector_cls = particle_reinjector_cls
    """
    particle_reinjector child of injections_child.
    """
    physical_models: physical_models_cls = physical_models_cls
    """
    physical_models child of injections_child.
    """
    initial_props: initial_props_cls = initial_props_cls
    """
    initial_props child of injections_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class geometry:
    fluent_name = ...
    child_names = ...
    parts = ...
    command_names = ...

    def list_topology(self, ):
        """
        'list_topology' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .user_specified_species import user_specified_species as user_specified_species_cls
from .species_1 import species as species_cls
class species_setting(Group):
    """
    Enter the species settings menu.
    """

    fluent_name = "species-setting"

    child_names = \
        ['user_specified_species', 'species']

    user_specified_species: user_specified_species_cls = user_specified_species_cls
    """
    user_specified_species child of species_setting.
    """
    species: species_cls = species_cls
    """
    species child of species_setting.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .solver import solver as solver_cls
from .adjust_solver_defaults_based_on_setup import adjust_solver_defaults_based_on_setup as adjust_solver_defaults_based_on_setup_cls
from .operating_conditions import operating_conditions as operating_conditions_cls
class general(Group):
    """
    'general' child.
    """

    fluent_name = "general"

    child_names = \
        ['solver', 'adjust_solver_defaults_based_on_setup',
         'operating_conditions']

    solver: solver_cls = solver_cls
    """
    solver child of general.
    """
    adjust_solver_defaults_based_on_setup: adjust_solver_defaults_based_on_setup_cls = adjust_solver_defaults_based_on_setup_cls
    """
    adjust_solver_defaults_based_on_setup child of general.
    """
    operating_conditions: operating_conditions_cls = operating_conditions_cls
    """
    operating_conditions child of general.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class plot_write_sample:
    fluent_name = ...
    command_names = ...

    def plot_sample(self, loaded_samples: str, variable_to_sampled: str, weighting_var: str, correlation_var: str, read_fn: str, overwrite: bool):
        """
        'plot_sample' command.
        
        Parameters
        ----------
            loaded_samples : str
                'loaded_samples' child.
            variable_to_sampled : str
                'variable_to_sampled' child.
            weighting_var : str
                'weighting_var' child.
            correlation_var : str
                'correlation_var' child.
            read_fn : str
                'read_fn' child.
            overwrite : bool
                'overwrite' child.
        
        """

    def write_sample(self, loaded_samples: str, variable_to_sampled: str, weighting_var: str, correlation_var: str, read_fn: str, overwrite: bool):
        """
        'write_sample' command.
        
        Parameters
        ----------
            loaded_samples : str
                'loaded_samples' child.
            variable_to_sampled : str
                'variable_to_sampled' child.
            weighting_var : str
                'weighting_var' child.
            correlation_var : str
                'correlation_var' child.
            read_fn : str
                'read_fn' child.
            overwrite : bool
                'overwrite' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_14 import option as option_cls
from .iterations_1 import iterations as iterations_cls
from .time_steps import time_steps as time_steps_cls
class frequency(Group):
    """
    Define the frequency at which cells in the register are marked for poor mesh numerics treatment.
    """

    fluent_name = "frequency"

    child_names = \
        ['option', 'iterations', 'time_steps']

    option: option_cls = option_cls
    """
    option child of frequency.
    """
    iterations: iterations_cls = iterations_cls
    """
    iterations child of frequency.
    """
    time_steps: time_steps_cls = time_steps_cls
    """
    time_steps child of frequency.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .dolly import dolly as dolly_cls
from .field_1 import field as field_cls
from .orbit import orbit as orbit_cls
from .pan import pan as pan_cls
from .position_1 import position as position_cls
from .projection import projection as projection_cls
from .roll import roll as roll_cls
from .target import target as target_cls
from .up_vector import up_vector as up_vector_cls
from .zoom import zoom as zoom_cls
class camera(Group):
    """
    'camera' child.
    """

    fluent_name = "camera"

    command_names = \
        ['dolly', 'field', 'orbit', 'pan', 'position', 'projection', 'roll',
         'target', 'up_vector', 'zoom']

    dolly: dolly_cls = dolly_cls
    """
    dolly command of camera.
    """
    field: field_cls = field_cls
    """
    field command of camera.
    """
    orbit: orbit_cls = orbit_cls
    """
    orbit command of camera.
    """
    pan: pan_cls = pan_cls
    """
    pan command of camera.
    """
    position: position_cls = position_cls
    """
    position command of camera.
    """
    projection: projection_cls = projection_cls
    """
    projection command of camera.
    """
    roll: roll_cls = roll_cls
    """
    roll command of camera.
    """
    target: target_cls = target_cls
    """
    target command of camera.
    """
    up_vector: up_vector_cls = up_vector_cls
    """
    up_vector command of camera.
    """
    zoom: zoom_cls = zoom_cls
    """
    zoom command of camera.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .face_name import face_name as face_name_cls
class list_face(Command):
    """
    'list_face' command.
    
    Parameters
    ----------
        face_name : str
            'face_name' child.
    
    """

    fluent_name = "list-face"

    argument_names = \
        ['face_name']

    face_name: face_name_cls = face_name_cls
    """
    face_name argument of list_face.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class compression_level(Integer):
    """
    0 => no compression, 1 => best compression speed; least compression, 9 => best compression ratio, slowetst speed.
    """

    fluent_name = "compression-level"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_2 import enabled as enabled_cls
from .option_name import option_name as option_name_cls
class enable_motion_transfer_across_interfaces(Command):
    """
    Transfer motion from one side of the interface to the other when only one side undergoes user-defined or system-coupling motion.
    
    Parameters
    ----------
        enabled : bool
            'enabled' child.
        option_name : str
            'option_name' child.
    
    """

    fluent_name = "enable-motion-transfer-across-interfaces"

    argument_names = \
        ['enabled', 'option_name']

    enabled: enabled_cls = enabled_cls
    """
    enabled argument of enable_motion_transfer_across_interfaces.
    """
    option_name: option_name_cls = option_name_cls
    """
    option_name argument of enable_motion_transfer_across_interfaces.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class materials:
    fluent_name = ...
    child_names = ...
    fluid = ...
    solid = ...
    mixture = ...
    inert_particle = ...
    droplet_particle = ...
    combusting_particle = ...
    particle_mixture = ...
    command_names = ...

    def list_materials(self, ):
        """
        'list_materials' command.
        """

    def copy_database_material_by_name(self, type: str, name: str):
        """
        'copy_database_material_by_name' command.
        
        Parameters
        ----------
            type : str
                'type' child.
            name : str
                'name' child.
        
        """

    def copy_database_material_by_formula(self, type: str, formula: str):
        """
        'copy_database_material_by_formula' command.
        
        Parameters
        ----------
            type : str
                'type' child.
            formula : str
                'formula' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name import file_name as file_name_cls
from .overwrite import overwrite as overwrite_cls
class write_sc_file(Command):
    """
    Write a Fluent Input File for System Coupling.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "write-sc-file"

    argument_names = \
        ['file_name', 'overwrite']

    file_name: file_name_cls = file_name_cls
    """
    file_name argument of write_sc_file.
    """
    overwrite: overwrite_cls = overwrite_cls
    """
    overwrite argument of write_sc_file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class playback:
    fluent_name = ...
    child_names = ...
    set_custom_frames = ...
    video = ...
    command_names = ...

    def read_animation(self, read_from_file: bool, animation_file_name: str, select_from_available: bool, animation_name: str):
        """
        Read new animation from file or already-defined animations.
        
        Parameters
        ----------
            read_from_file : bool
                'read_from_file' child.
            animation_file_name : str
                'animation_file_name' child.
            select_from_available : bool
                'select_from_available' child.
            animation_name : str
                'animation_name' child.
        
        """

    def write_animation(self, format_name: str):
        """
        Write animation sequence to the file.
        
        Parameters
        ----------
            format_name : str
                'format_name' child.
        
        """

    def stored_view(self, view: bool):
        """
        Play the 3D animation sequence using the view stored in the sequence.
        
        Parameters
        ----------
            view : bool
                Yes: "Stored View", no: "Different View".
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .motion_type import motion_type as motion_type_cls
from .constant_velocity import constant_velocity as constant_velocity_cls
from .zone_track import zone_track as zone_track_cls
class motion(Group):
    """
    'motion' child.
    """

    fluent_name = "motion"

    child_names = \
        ['motion_type', 'constant_velocity', 'zone_track']

    motion_type: motion_type_cls = motion_type_cls
    """
    motion_type child of motion.
    """
    constant_velocity: constant_velocity_cls = constant_velocity_cls
    """
    constant_velocity child of motion.
    """
    zone_track: zone_track_cls = zone_track_cls
    """
    zone_track child of motion.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .maximum_radiation_iterations import maximum_radiation_iterations as maximum_radiation_iterations_cls
from .residual_convergence_criteria import residual_convergence_criteria as residual_convergence_criteria_cls
class radiosity_solver_control(Group):
    """
    'radiosity_solver_control' child.
    """

    fluent_name = "radiosity-solver-control"

    child_names = \
        ['maximum_radiation_iterations', 'residual_convergence_criteria']

    maximum_radiation_iterations: maximum_radiation_iterations_cls = maximum_radiation_iterations_cls
    """
    maximum_radiation_iterations child of radiosity_solver_control.
    """
    residual_convergence_criteria: residual_convergence_criteria_cls = residual_convergence_criteria_cls
    """
    residual_convergence_criteria child of radiosity_solver_control.
    """
